      subroutine ANGPOS(DALPH0,DDELT0,DALPHA,DDELTA,DPOS,IERR)
C
CC    Calculates the position angle
C
C************************ FFORM VERSION 1.2 ************ 19-FEB-91 18:21
C
CA  author : KOD        date: 06-FEB-1991 19:24
CU  update : KOD        date: 19-FEB-1991 18:21
C
CT  status: tested
C
C   general description
CG
CG  Subroutine to calculate the position angle between two positions.
CG  This value is defined as the angle between the great circle
CG  passing through both positions and the local north meridian as
CG  seen from the position (DALPH0, DDELT0). It is counted
CG  counterclockwise from North over East, South, West to North.
C
C   call_var.          type I/O description
CP
CP  DALPH0              R8      Right Ascension of reference  (radians)
CP  DDELT0              R8  I   Declination     of reference  (radians)
CP
CP  DALPHA              R8  I   Right Ascension               (radians)
CP  DDELTA              R8  I   Declination                   (radians)
CP
CP  DPOS                R8    O position angle                (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  EULER1              SR      general coordinate transformation
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
CR  DRADRS                      'resets' radians
CR  ERRSTC              SR      continue error stack for one level
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DALPH0, DDELT0, DALPHA, DDELTA, DPOS,
     &              D1, D2, D3, DPH1, DTH1, DPH2, DTH2, DRADRS
      REAL*4        HFLAG
      INTEGER*4     IERR, IOS, ISTAT
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'ANGPOS'/
C
      IERR = 0
C
      if (max(abs(DALPH0),abs(DALPHA)).gt.D2PI) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,'Unusual value for the R.A.')
      endif
C
      if (max(abs(DDELT0), abs(DDELTA)).gt.DPID2) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input parameters')
      endif
C
C
      if (IERR.lt.2) then
C
        D1 =  DRADRS ( DPID2 + DALPH0 )
        D2 =  DPID2 - DDELT0
        D3 =  0.D0
C
        DPH1 = DALPHA
        DTH1 = DPID2 - DDELTA
C
        call EULER1(D1,D2,D3,DPH1,DTH1,DPH2,DTH2,ISTAT)
C
        if (ISTAT.gt.0) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
C
        else
C
          DPOS = DRADRS ( DPID2 - DPH2 )
C
        endif
C
      endif
C
C
      RETURN
      END
