! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine CHWDAY(DJD,CHDAY,IERR)
C
CC    Determines the Day of Week out of the Julian Date
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:53
C
CA  author : KOD        date: 23-AUG-1989 19:23
CU  update : KOD        date: 28-MAR-1990 19:14
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the Day of Week out of the Julian Date,
CG  according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.27 .
C
C   call_var.          type I/O description
CP  DJD                 R8  I   Julian Date
CP
CP  CHDAY               C   I/O string containing the day of week
CP                              useful lengths of CHDAY: 2,3,9 charact.
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DJD
      REAL*4        HFLAG
      INTEGER*4     IERR, IOS, IDAY, N, ISTAT
      CHARACTER*(*) CHDAY
      CHARACTER*9   CHDAYS(7)
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CHWDAY'/
C
      DATA          CHDAYS / 'Monday   ' , 'Tuesday  ' , 'Wednesday' ,
     &                       'Thursday ' , 'Friday   ' , 'Saturday ' ,
     &                       'Sunday   ' /
C
      IERR = 0
C
      if (DJD.lt.0.D0 .or. DJD.gt.2999773.5D0) then
        IERR = 2
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
      if (IERR.lt.2) then
C
        ISTAT = 1
        N = len(CHDAY)
        if (N.eq.2 .or. N.eq.3 .or. N.eq.9) ISTAT = 0
C
        if (ISTAT.ne.0) then
          IERR = max(IERR,ISTAT)
          call WRERR(RTNAME,IERR,'Warning: unusual length of CHDAY')
        endif
C
        IDAY = int(DJD + 0.5D0)
        IDAY = MOD(IDAY,7) + 1
C
        CHDAY=CHDAYS(IDAY)(1:N)
C
      endif
C
C
      RETURN
      END
