! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine CNVFRC(LPLUS,IINT,IM,SEC,DDMS,IERR)
C
CC    Converts minutes and seconds into a decimal fraction
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:54
C
CA  author : KOD        date: 19-JUL-1989 18:31
CU  update : KOD        date: 20-MAR-1990 14:41
C
CT  status: tested
C
C   general description
CG  Subroutine to convert minutes and seconds into a decimal fraction
CG  of degrees (or hours) and to append it to the degree (or hour)
CG  value.
CG  The sign has to be given explicitely; the values for IINT,IM,SEC
CG  should be positive, possible signs there will be ignored.
C
C   call_var.          type I/O description
CP  LPLUS               L4  I   sign (LPLUS=.true. for positive values)
CP  IINT                I4  I   integer part (degrees or hours)
CP  IM                  I4  I   minutes
CP  SEC                 R4  I   seconds
CP
CP  DDMS                R8    O decimal value (degrees or hours)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DDMS, DM, DS, DH
      REAL*4        HFLAG, SEC
      INTEGER*4     IERR ,IOS, IINT, IM
      LOGICAL*4     LPLUS
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CNVFRC'/
C
      IERR = 0
C
      DM = dabs(dble(IM))
      DS = dabs(dble(SEC))
C
      if (dmax1(DM,DS).ge.60.D0) then
C
        IERR = 2
        call WRERR(RTNAME,IERR,'Error in input parameters DM,DS')
C
      else
C
         DH = dabs(dble(IINT)) + ( DM + DS/60.D0 ) / 60.D0
C
         if (LPLUS) then
            DDMS =  DH
         else
            DDMS = -DH
         endif
C
      endif
C
      RETURN
      END
