! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      real*8 function DHRRES(DHR)
C
CC    'Resets' hours to the interval  0 .. 24
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:57
C
CA  author : KOD        date: 19-JUL-1989 18:31
CU  update : KOD        date: 28-MAR-1990 20:18
C
CT  status: tested
C
C   general description
CG  'Resets' hours to the interval  0 .. 24.
C
C   call_var.          type I/O description
CP  DHR                 R8  I   hours (may be negative)
CP  DHRRES              R8      hours inside the interval  0 .. 24
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  RESVAL              SR      'resets' periodic variables
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DHR, DXMIN, DXMAX, DXOLD, DXNEW
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'DHRRES'/
C
      IERR = 0
C
      DXMIN =  0.D0
      DXMAX = 24.D0
      DXOLD = DHR
C
      CALL RESVAL(DXMIN,DXMAX,DXOLD,DXNEW,ISTAT)
C
      if (ISTAT.gt.1) then
        IERR = max(IERR,ISTAT)
        call ERRSTC(RTNAME,10)
      endif
C
      if (IERR.lt.2) DHRRES = DXNEW
C
      RETURN
      END
