! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine DISTP1(DDIST,DPRLX,IERR)
C
CC    Calculates the parallax for a given distance
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:57
C
CA  author : KOD        date: 04-OCT-1989 19:49
CU  update : KOD        date: 20-MAR-1990 14:47
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the parallax for a given distance,
CG  according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.143 .
C
C   call_var.          type I/O description
CP  DDIST               R8  I   distance of the object  (Astr.Units)
CP
CP  DPRLX               R8    O corresponding parallax  (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DDIST, DPRLX, DF
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS
      CHARACTER*8   RTNAME
C
      parameter ( DF = 4.2634515D-5 )
C
      DATA          RTNAME /'DISTP1'/
C
      IERR = 0
C
      if (DDIST.le.0.D0) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in the input parameter DDIST')
      else
        DPRLX = asin ( DF / DDIST )
      endif
C
      RETURN
      END
