! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine JDDAT1(DJD,DT,IERR)
C
CC    Calculates the Calendar Date out of the Julian Date
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:04
C
CA  author : KOD        date: 22-AUG-1989 17:28
CU  update : KOD        date: 29-MAR-1990 15:44
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the Calendar Date out of the Julian Date.
CG
CG  The calendar date will be given in the Gregorian system for
CG  dates starting with October 15, 1582, and in the Julian system
CG  until October 4, 1582  (which precedes the Oct.15 immediately).
CG
CG  This subroutine is valid for the years  -4712  to  +3500 ,
CG  (cf. 'Sky and Telescope, May 1984, p.455) and has been written
CG  according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.26 .
C
C   call_var.          type I/O description
CP  DJD                 R8  I   Julian Date
CP
CP  DT                  R8    O Calendar Date (YYYYMMDD.HHMMSSS)
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  JDCAL1              SR      Julian Date to Calendar Date
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DJD, DT, DJ
      REAL*4        HFLAG, SEC
      INTEGER*4     IERR ,IOS, IYR, IMTH, IDAY, IHR, IMIN, MSEC, ISTAT
      CHARACTER*19  CH19
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'JDDAT1'/
C
      IERR=0
C
      DJ = DJD
      call JDCAL1(DJ,IYR,IMTH,IDAY,IHR,IMIN,SEC,ISTAT)
CN!     ERROR handling
        if  (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      MSEC = INT(SEC*1.E3)
C
      WRITE(CH19,10) IYR, IMTH, IDAY, IHR, IMIN, MSEC
   10 FORMAT(I5,2I2.2,'.',2I2.2,I5.5)
      READ(CH19,'(F17.7)') DT
C
      RETURN
      END
