! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      SUBROUTINE CALJD2(ITD,ITS,DJD,IERR)
C
CC    Calculates the Julian Date out of the Calendar Date.
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:33
C
CA  author : KOD        date: 12-MAR-1992 14:25
CU  update : KOD        date: 16-MAR-1992 16:04
C
CT  status: not tested
C
C   general description 
CG
CG  This subroutine calculates the Julian Date out of the Canedar Date
CG  for the years 1950 to 2049. The Calendar Date is contained in the
CG  integers values ITD (YYMMDD) and ITS (msec of the day in UT).
C
C   call_var.          type I/O description 
CP  ITD                 I4  I   Calendar Date  (YYMMDD)
CP  ITS                 I4  I   Universal Time (msec of the day)
CP  DJD                 R8  ?/? Julian Date
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description 
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
CR  CALJD1              SR      calendar to JD conversion
CR  ERRSTC              SR      continue error stack for one level
CR  WRERR               SR      formats error code in standard form
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
C
      REAL*8        DJD
      REAL*4        HFLAG, SEC
      INTEGER*4     IERR, IOS, ISTAT, ITD, ITS, IY, IM, ID, IHR, IMT, IH
      LOGICAL       LCHECK
      CHARACTER*6   CH6
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CALJD2'/
C
D     IF (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
      LCHECK = .true.
C
C     simple check of input values:
C
      if (ITD.lt.0 .or. ITS.lt.0 .or. ITS.gt.86400000) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in ITD or ITS')
      endif
C
C
      if (IERR.lt.2) then
C
C       determine the year, month, day:
C
        write(CH6,'(I6)') ITD
        read(CH6,'(3I2)') IY,IM,ID
C
        if (IY.lt.50) then
          IY = 2000 + IY
        else
          IY = 1900 + IY
        endif
C
C       determine the hour, minute, second:
C
        IHR = ITS / 3600000
        IH  = IHR * 3600000
        IMT = (ITS - IH) / 60000
        SEC = 0.001 * real(ITS - IH - IMT * 60000)
C
C       calculate the Julian Date:
C
        call CALJD1(IY,IM,ID,IHR,IMT,SEC,LCHECK,DJD,ISTAT)
C
        if  (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      endif
C
D     IF (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
      RETURN
      END
