! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine CHDATE(IY,IM,ID,IHR,IMT,SEC,LCHECK,CHDAT,IERR)
C
CC    Produces a string of the form 'YYYY.MM.DD / HH:MM:SS.SS'
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:33
C
CA  author : KOD        date: 19-JUL-1989 18:31
CU  update : KOD        date: 28-MAR-1990 19:33
CU  update : KOD        date: 30-MAR-1990 16:50
C
CT  status: tested (08-AUG-1989 19:29 / KOD)
C
C   general description 
CG
CG  Subroutine to produce a string of the form
CG  'YYYY.MM.DD / HH:MM:SS.SS'  (Maximum resolution: 10 msec).
CG  There will be a rough check on the validity of the given date;
CG  a detailed check is also possible (see LCHECK).
C
C   call_var.          type I/O description 
CP  IY                  I4  I   year         (-999 .. +9999)
CP  IM                  I4  I   month        (1 .. 12)
CP  ID                  I4  I   day of month (1 .. 28,29,30,31)
CP  IHR                 I4  I   hours        (0 .. 23)
CP  IMT                 I4  I   minutes      (0 .. 59)
CP  SEC                 R4  I   seconds      (0.0 .. 59.999...)
CP  LCHECK              L4  I   extended input check if LCHECK=.true.
CP  CHDAT               C   I/O string containing the calendar date
CP                              'YYYY' to 'YYYY.MM.DD / HH:MM:SS.SS'
CP                               possible lengths 'L' of CHDAT :
CP                               L =  4 : 'YYYY'
CP                               L =  7 : 'YYYY.MM'
CP                               L = 10 : 'YYYY.MM.DD'
CP                               L = 15 : 'YYYY.MM.DD / HH'
CP                               L = 18 : 'YYYY.MM.DD / HH:MM'
CP                               L = 21 : 'YYYY.MM.DD / HH:MM:SS'
CP                               L = 23 : 'YYYY.MM.DD / HH:MM:SS.S'
CP                               L = 24 : 'YYYY.MM.DD / HH:MM:SS.SS'
CP                               The values for the year, month
CP                               and day will not be rounded,
CP                               the values for the hour, minute
CP                               and second will be rounded.
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description 
CR  JDCAL1              SR      Julian Date to Calendar Date
CR  CALJD1              SR      Calendar Date to Julian Date
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
C
      REAL*8        DJD
      REAL*4        HFLAG, SEC, F, FSEC, H, SEC1
      INTEGER*4     IERR ,IOS, IY, IM, ID, IHR, IMT, N, NDIG, ISEC,
     &              ISEC1, ISEC2, IY1, IM1, ID1, IHR1, IMT1,
     &              I1, I2, ISTAT
      LOGICAL*4     LCHECK, LCHK
      CHARACTER*3   CHDIG
      CHARACTER*(*) CHDAT
      CHARACTER*70  CHFMT
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CHDATE'/
C
D     if (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) then
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
C     determine length of string:
C
      N = len(CHDAT)
C
C     check length of string:
C
      ISTAT = 1
      if (N.eq. 4 .or. N.eq. 7 .or. N.eq.10 .or. N.eq.15 .or.
     &    N.eq.18 .or. N.eq.21 .or. N.eq.23 .or. N.eq.24)  ISTAT = 0
C
      IERR = max(IERR,ISTAT)
C
      if (IERR.gt.0)
     &   call WRERR(RTNAME,IERR,'Error in length of parameter CHDAT')
C
C     (rough) check for meaningful date:
c
      if (IY .lt.-999 .or.  IY.gt.9999  .or.
     &    IM .lt.1    .or.  IM.gt.12    .or.
     &    ID .lt.1    .or.  ID.gt.31    .or.
     &    IHR.lt.0    .or.  IHR.gt.23   .or.
     &    IMT.lt.0    .or.  IMT.gt.59   .or.
     &    SEC.lt.0.0  .or.  SEC.gt.60.0) then
C
        ISTAT = 2
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in input parameters IY .. SEC')
C
      endif
C
C
C     precise check for valid date:
C
      if (IERR.lt.2) then
C
C       copy input parameters:
C
        IY1  = IY
        IM1  = IM
        ID1  = ID
        IHR1 = IHR
        IMT1 = IMT
        SEC1 = SEC
C
        if (LCHECK) then
C
          LCHK = LCHECK
          call CALJD1(IY1,IM1,ID1,IHR1,IMT1,SEC1,LCHK,DJD,ISTAT)
C
          if (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,10)
          endif
C
        endif
C
        SEC1 = SEC-1.E-6
C
C       round values:
C
        NDIG  = min( max(N-22,0), 3 )
        F     = real( 10**NDIG )
        ISEC  = nint( SEC1*F )
        FSEC  = real( ISEC ) / F
        ISEC1 = int( FSEC )
        ISEC2 = ISEC - ISEC1 * 10**NDIG
C
C
C       increase minutes:
C
        if ( (ISEC1.ge.60) .or.
     &       (N.le.18 .and. SEC1.gt.30.0) ) then
          SEC1  = 0.0
          ISEC1 = 0
          ISEC2 = 0
          IMT1 = IMT1 + 1
        endif
C
C
C       increase hours:
C
        if ( (IMT1.ge.60) .or.
     &       (N.le.15 .and.
     &        (IMT1.gt.30 .or. (IMT1.eq.30 .and. SEC1.gt.0.0))) ) then
          SEC1  = 0.0
          ISEC1 = 0
          ISEC2 = 0
          IMT1 = 0
          IHR1 = IHR1 + 1
        endif
C
C
C       increase the day:
C
        if (IHR1.eq.24) then
C
          IHR1 = 0
C
          LCHK=.true.
          call CALJD1(IY1,IM1,ID1,IHR1,IMT1,SEC1,LCHK,DJD,ISTAT)
C
          if (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,20)
          endif
C
          if (IERR.lt.2) then
            DJD = DJD + 1.D0
            call JDCAL1(DJD,IY1,IM1,ID1,IHR1,IMT1,SEC1,ISTAT)
C
            if (ISTAT.gt.1) then
              IERR = max(IERR,ISTAT)
              call ERRSTC(RTNAME,30)
            endif
C
          endif
        endif
C
C
C       assign result to CHDAT:
C
        if (N.eq. 4) write(CHDAT, 4) IY1
        if (N.eq. 7) write(CHDAT, 7) IY1,IM1
        if (N.eq.10) write(CHDAT,10) IY1,IM1,ID1
        if (N.eq.15) write(CHDAT,15) IY1,IM1,ID1,IHR1
        if (N.eq.18) write(CHDAT,18) IY1,IM1,ID1,IHR1,IMT1
        if (N.eq.21) write(CHDAT,21) IY1,IM1,ID1,IHR1,IMT1,ISEC1
        if (N.GE.23) then
           write(CHDIG,'(I1,''.'',I1)') NDIG,NDIG
           CHFMT='(I4,''.'',I2.2,''.'',I2.2,'' / '',' //
     $           'I2.2,'':'',I2.2,'':'',I2.2,''.'',I' // CHDIG // ')'
           write(CHDAT,CHFMT) IY1,IM1,ID1,IHR1,IMT1,ISEC1,ISEC2
        endif
      endif
C
    4 FORMAT(I4)
    7 FORMAT(I4,'.',I2.2)
   10 FORMAT(I4,'.',I2.2,'.',I2.2)
   15 FORMAT(I4,'.',I2.2,'.',I2.2,' / ',I2.2)
   18 FORMAT(I4,'.',I2.2,'.',I2.2,' / ',I2.2,':',I2.2)
   21 FORMAT(I4,'.',I2.2,'.',I2.2,' / ',I2.2,':',I2.2,':',I2.2)
C
C
D     if (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) then
D       write (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      RETURN
      END
