! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine CHDEG1(DRAD,CHDG,IERR)
C
CC    Converts radians into degrees and writes a string 'DDD:MM:SS.SSSS'
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:33
C
CA  author : KOD        date: 22-AUG-1989 16:41
CU  update : KOD        date: 28-MAR-1990 19:08
C
CT  status: tested
C
C   general description 
CG  Subroutine to convert radians into a degrees and write a string
CG  of the form 'DDD:MM:SS.SSSS'
C
C   call_var.          type I/O description 
CP  DRAD                R8  I   angle to be converted (rad,-pi/2..2*pi)
CP  CHDG                C   I/O string containing the degrees
CP                              'DDD:MM:SS.SSSS'
CP                               possible lengths 'L' of CHDG :
CP                               L =  3 : 'DDD'
CP                               L =  6 : 'DDD:MM'
CP                               L =  9 : 'DDD:MM:SS'
CP                               L = 11 : 'DDD:MM:SS.S'
CP                               L = 12 : 'DDD:MM:SS.SS'
CP                               L = 13 : 'DDD:MM:SS.SSS'
CP                               L = 14 : 'DDD:MM:SS.SSSS'
CP                               In each case the values
CP                               will be rounded appropriately;
CP                               the value of DDD must be greater
CP                               than -99 and less than 999.
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
CI  R_INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description 
CR  CNVDMS              SR      splits decimal degrees
CR  HFLAG               R4      output flag handling routine
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
      INCLUDE 'R_INCLUDE:IGENL.INC'
C
      REAL*8        DRAD, DDG, DDGABS
      REAL*4        HFLAG, RSEC, FSEC, F
      INTEGER*4     IERR ,IOS, IDG, IMIN, N, NDIG, ISEC, ISEC1, ISEC2,
     &              ISTAT
      LOGICAL*4     LUNIT, LPLUS, LH
      CHARACTER*3   CHDIG
      CHARACTER*35  CHFMT
      CHARACTER*(*) CHDG
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CHDEG1'/
C
D     IF (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
C     initialize values:
C
      N = len(CHDG)
      DDG = DRAD * D180PI
      LUNIT = (DDG.ge.-90.D0 .and. DDG.lt.360.D0)
C
C     check input values:
C
      ISTAT = 1
      if (N.eq.3 .or. N.eq.6 .or. N.eq.9 .or. (N.ge.11 .and. N.le.14))
     &  ISTAT = 0
      if (ISTAT.ne.0) then
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in length of CHDG')
        N = min(N,14)
      endif
C
      ISTAT = 0
      if (DDG.lt. -90.D0 .or. DDG.ge. 360.D0) ISTAT = 1
      if (DDG.le.-100.D0 .or. DDG.ge.1000.D0) ISTAT = 2
C
      if (ISTAT.ne.0) then
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in the input parameter DDG')
      endif
C
C
      if (IERR.lt.2) then
C
C       store sign:
C
        LPLUS = (DDG.ge.0.D0)
        DDGABS = dabs(DDG)
C
C       extract hours, minutes and seconds:
C
        call CNVDMS(DDGABS,LH,IDG,IMIN,RSEC,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      endif
C
C
      if (IERR.lt.2) then
C
C       round values:
C
        NDIG = max(N-10,0)
        F = real(10**NDIG)
        ISEC = nint(RSEC*F)
        FSEC = real(ISEC)/F
        ISEC1 = int(FSEC)
        ISEC2 = ISEC - ISEC1*10**NDIG
        RSEC  = nint(RSEC*10000)*1.E-4
C
        if ( (ISEC1.ge.60) .or.
     &      (N.le.6 .and. (ISEC1.gt.30 .or. RSEC.gt.30.0)) ) then
          RSEC  = 0.0
          ISEC1 = 0
          ISEC2 = 0
          IMIN  = IMIN + 1
        endif
C
        if ( (IMIN.ge.60) .or.
     &       (N.eq.3 .and.
     &        (IMIN.gt.30 .or. (IMIN.eq.30 .and. RSEC.gt.0.0))) ) then
          RSEC  = 0.0
          ISEC1 = 0
          ISEC2 = 0
          IMIN  = 0
          IDG   = IDG + 1
        endif
C
        if (LUNIT .and. IDG.ge.360) IDG = IDG - 360
C
        if (.not.LPLUS .and. IDG.eq.0) then
          if (N.eq. 3) LPLUS=.true.
          if (N.eq. 6 .and. IMIN.eq.0) LPLUS=.true.
          if (N.eq. 9 .and. IMIN.eq.0 .and. ISEC1.eq.0) LPLUS=.true.
          if (N.ge.11 .and. IMIN.eq.0 .and. ISEC1.eq.0 .and. ISEC2.eq.0)
     &       LPLUS=.true.
        endif
C
        if (.not.LPLUS) IDG = -IDG
C
C       assign result to CHDG:
C
        if (N.eq.3) write(CHDG,'(I3.1)') IDG
        if (N.eq.6) write(CHDG,'(I3.1,'':'',I2.2)') IDG,IMIN
        if (N.eq.9) write(CHDG,'(I3.1,'':'',I2.2,'':'',I2.2)') IDG,IMIN,
     &                                                         ISEC1
        if (N.ge.11) then
           write(CHDIG,'(I1,''.'',I1)') NDIG,NDIG
           CHFMT = '(I3.1,'':'',I2.2,'':'',I2.2,''.'',I' // CHDIG // ')'
           write(CHDG,CHFMT) IDG,IMIN,ISEC1,ISEC2
        endif
C
        if (.not.LPLUS .and. IDG.eq.0) CHDG(2:2)='-'
C
      endif
C
D     IF (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      RETURN
      END
