! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine CHHR2(DRAD,CHHR,IERR)
C
CC    Converts radians into hours and writes a string 'HH:MM.MMMMM'
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:34
C
CA  author : KOD        date: 28-AUG-1989 15:04
CU  update : KOD        date: 28-MAR-1990 19:13
C
CT  status: tested
C
C   general description 
CG  Subroutine to convert radians into a hours and write a string
CG  of the form 'HH:MM.MMMMM'
C
C   call_var.          type I/O description 
CP  DRAD                R8  I   angle to be converted (rad,0..2*pi)
CP  CHHR                C   I/O  string containing the hours
CP                              'HH:MM.MMMMM'
CP                               possible lengths 'L' of CHHR :
CP                               L =  2 : 'HH'
CP                               L =  5 : 'HH:MM'
CP                               L =  7 : 'HH:MM.M'
CP                               L =  8 : 'HH:MM.MM'
CP                               L =  9 : 'HH:MM.MMM'
CP                               L = 10 : 'HH:MM.MMMM'
CP                               L = 11 : 'HH:MM.MMMMM'
CP                               In each case the values
CP                               will be rounded appropriately;
CP                               the value of HH must be positive
CP                               (or zero) and less than 100.
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
CI  R_INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description 
CR  CNVDMS              SR      splits decimal degrees
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
      INCLUDE 'R_INCLUDE:IGENL.INC'
C
      REAL*8        DRAD, DHR
      REAL*4        HFLAG, RMIN, RSEC, F
      INTEGER*4     IERR ,IOS, IHR, IMIN, N, NDIG, IMIN1, ISTAT
      LOGICAL*4     LUNIT, LH
      CHARACTER*3   CHDIG
      CHARACTER*33  CHFMT
      CHARACTER*(*) CHHR
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CHHR2 '/
C
D     IF (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
C     initialize values:
C
      N = len(CHHR)
      DHR = DRAD * 24.D0 / D2PI
      LUNIT = (DHR.ge.0.D0 .and. DHR.lt.24.D0)
C
C     check input values:
C
      ISTAT = 1
      if (N.eq.2 .or. N.eq.5 .or. (N.ge.7 .and. N.le.11))
     &  ISTAT = 0
      if (ISTAT.ne.0) then
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in length of CHHR')
        N = min(N,11)
      endif
C
      ISTAT = 0
      if (DHR.ge.24.D0) ISTAT = 1
      if (DHR.lt.0.D0 .or. DHR.ge.100.D0) ISTAT = 2
C
      if (ISTAT.ne.0) then
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in the input parameter DHR')
      endif
C
C
      if (IERR.lt.2) then
C
C       extract hours, minutes and seconds:
C
        call CNVDMS(DHR,LH,IHR,IMIN,RSEC,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        else
          RMIN = RSEC / 60.0
        endif
      endif
C
C
      if (IERR.lt.2) then
C
C       round values:
C
        NDIG = max(N-6,0)
        F = real(10**NDIG)
        IMIN1 = nint(RMIN*F)
C
        if ( (IMIN1.eq.10**NDIG) .or.
     &       (N.le.5 .and. (IMIN1.gt.0.5*F .or. RMIN.gt.0.5)) ) then
          RMIN = 0.0
          IMIN1 = 0
          IMIN = IMIN + 1
        endif
C
        if ( (IMIN.ge.60) .or.
     &       (N.eq.2 .and.
     &        (IMIN.gt.30 .or. (IMIN.eq.30 .and. RMIN.gt.0.0))) ) then
          RMIN = 0.0
          IMIN = 0
          IHR = IHR + 1
        endif
C
        if (LUNIT .and. IHR.ge.24) IHR = IHR - 24
C
C       assign result to chhr:
C
        if (N.eq.2) write(CHHR,'(I2.2)') IHR
        if (N.eq.5) write(CHHR,'(I2.2,'':'',I2.2)') IHR,IMIN
        if (N.ge.7) then
           write(CHDIG,'(I1,''.'',I1)') NDIG,NDIG
           CHFMT = '(I2.2,'':'',I2.2,''.'',I' // CHDIG // ')'
           write(CHHR,CHFMT) IHR,IMIN,IMIN1
        endif
C
      endif
C
D     IF (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      RETURN
      END
