! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine CNVDMS(DDEG,LPLUS,IDEG,IMIN,RSEC,IERR)
C
CC    Calculates minutes and seconds out of a decimal number
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:34
C
CA  author : KOD        date: 19-JUL-1989 18:31
CU  update : KOD        date: 28-MAY-1991 10:46  ( IMIN,RSEC < 60 )
C
CT  status: tested
C
C   general description 
CG  Subroutine to calculate the minutes and seconds out of a decimal
CG  number (degrees or hours). Negative values are allowed.
C
C   call_var.          type I/O description 
CP  DDEG                R8  I   number to be converted (degr. or hours)
CP  LPLUS               L4    O sign of DDEG ( > 0  if  LPLUS=.true.)
CP  IDEG                I4    O integer part (positive, degr. or hours)
CP  IMIN                I4    O minutes (positive, < 60 )
CP  RSEC                R4    O seconds (positive, < 60 )
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description 
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
C
      REAL*8        DDEG, DH
      REAL*4        HFLAG, RSEC
      INTEGER*4     IERR ,IOS, IDEG, IMIN
      LOGICAL*4     LPLUS
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CNVDMS'/
C
D     IF (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
      if (abs(DDEG).gt.1.D3) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,'Possible error in input parameters')
      endif
C
      LPLUS = (DDEG.ge.0.D0)
C
      DH   = dabs(DDEG)
      IDEG = idint(DH)
      IMIN = idint((DH-dble(IDEG))*60.D0)
      RSEC = sngl(((DH-dble(IDEG))*60.D0-dble(IMIN))*60.D0)
C
      if (RSEC.ge.60.0) then
        RSEC = 0.0
        IMIN = IMIN + 1
      endif
C
      if (IMIN.ge.60) then
        IMIN = 0
        IDEG = IDEG + 1
      endif
C
D     IF (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      RETURN
      END
