! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine DMSDEC(DDMMSS,DDEG,IERR)
C
CC    Calc. the value of a number given as 'DDD.MMSSS' or 'HH.MMSSS'
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:35
C
CA  author : KOD        date: 22-AUG-1989 15:48
CU  update : KOD        date: 20-MAR-1990 14:48
C
CT  status: tested
C
C   general description 
CG  Subroutine to calculate the value of a number given in the form
CG  'DDD.MMSSS' or 'HH.MMSSS'. Negative values are allowed.
C
C   call_var.          type I/O description 
CP  DDMMSS              R8  I   number to be converted (-360 .. 360)
CP                              (DDD.MMSSS or HH.MMSSS)
CP  DDEG                R8    O corresponding decimal value
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description 
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
C
      REAL*8        DDMMSS, DDEG, DMS
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, IDEG, IMT, ISEC1, ISEC2
      LOGICAL*4     LPLUS
      CHARACTER*8   RTNAME
      CHARACTER*19  CHDEG19
C
      DATA          RTNAME /'DMSDEC'/
C
D     IF (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
      LPLUS = (DDMMSS.ge.0.D0)
C
      DMS = dabs(DDMMSS)
      if (DMS.gt.360.D0) then
        IERR = 1
        if (DMS.ge.1.D6) IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input parameter DDMMSS')
      endif
C
      if (IERR.lt.2) then
C
C       split input value:
C
        write(CHDEG19,'(F19.12)') DMS
C
C       read individual parts:
C
        read(CHDEG19,'(I6,1X,I2,I2,I8)') IDEG, IMT, ISEC1, ISEC2
C
        if (max(IMT,ISEC1).ge.60) then
          IERR = max(IERR,2)
          call WRERR(RTNAME,IERR,'Error in input parameter DDMMSS')
        else
          DDEG = dble(IDEG) + dble(IMT)/60.D0 + dble(ISEC1)/3600.D0
     &                                        + dble(ISEC2)/3600.D8
          if (.not.LPLUS) DDEG = -DDEG
        endif
C
      endif
C
D     IF (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      RETURN
      END
