! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      SUBROUTINE FLDLIM(NZONE,IFIELD,IRAMIN,IRAMAX,IDEMIN,IDEMAX,IERR)
C
CC  calculate border lines of FIELD
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:36
C
CA  author : GRU        date: 25-OCT-1989 16:53
CU  update : GRU        date: 10-AUG-1994 18:00
CU  update : CRI        date: 11-AUG-1994 15:15 reset IERR
C
CT  status: not tested
C
C   general description 
CG
C
C   call_var.          type I/O description 
CP  NZONE               I4  ?/? # of zones used for field definition
CP  IFIELD              I4  ?/? field#
CP  IRAMAX              I4  ?/? upper RA border of field [0.5 arcsec]
CP  IRAMIN              I4  ?/? lower RA border of field [0.5 arcsec]
CP  IDEMAX              I4  ?/? upper DEC border of field [0.5 arcsec]
CP  IDEMIN              I4  ?/? lower DEC border of field [0.5 arcsec]
CP  IERR                I4    O error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description 
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
CR  ERRSTC              SR      
CR  FLDCNV              SR      convert field# to longitudinal and
CR                              latitudinal zones
CR  ZONLIM              SR      determine field boundaries
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
C
      REAL*4        HFLAG
      INTEGER*4     IERR,IOS,IFIELD,IRAMIN,IRAMAX,IDEMIN,IDEMAX,
     *              ISTAT,LAT,LON,NZONE
      CHARACTER     RTNAME*8,FLAG*6
C
      DATA          RTNAME /'FLDLIM'/
C
D     IF (HFLAG(RTNAME,'in: SEQ# ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) IFIELD
D 101   FORMAT ( I)
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
C**********************************************************************
C generate latitude and longitude zones from field#
      FLAG = 'TOZONE'
      CALL FLDCNV(LAT,LON,IFIELD,FLAG,ISTAT)
      IF (ISTAT.GT.1) THEN
         IERR=3
         CALL ERRSTC(RTNAME,2)
      ELSE
         CALL ZONLIM(NZONE,LAT,LON,IRAMIN,IRAMAX,IDEMIN,IDEMAX,ISTAT)
         IF (ISTAT.GT.1) THEN
            IERR=3
            CALL ERRSTC(RTNAME,2)
         ENDIF
      ENDIF
C
D     IF (HFLAG(RTNAME,'out: IERR').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) IERR
D9901   FORMAT (I)
D       CALL WRFLAG(OUTPT)
D     ENDIF
      RETURN
      END
