! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine HMMRAD(DHMMM,DRAD,IERR)
C
CC    Calculates radians of a number given in the form 'HH.MMMM'
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:36
C
CA  author : KOD        date: 05-SEP-1989 18:41
CU  update : KOD        date: 29-MAR-1990 15:32
C
CT  status: tested
C
C   general description 
CG  Subroutine to convert a number given in the form 'HH.MMMM'
CG  (hours) into radians. Negative values are allowed.
C
C   call_var.          type I/O description 
CP  DHMMM               R8  I   number to be converted (-24 .. 24)
CP                              (HH.MMMM)
CP  DRAD                R8    O corresponding radians
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
CI  R_INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description 
CR  DMMDEC              SR      converts 'HH.MMMM' into dec. hours
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
      INCLUDE 'R_INCLUDE:IGENL.INC'
C
      REAL*8        DHMMM, DRAD, DHR, DH
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'HMMRAD'/
C
D     IF (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
      if (dabs(DHMMM).gt.24.D0) then
        IERR = 1
        call WRERR(RTNAME,IERR,'Error in input parameter DHMMM')
      endif
C
      DH = DHMMM
      call DMMDEC(DH,DHR,ISTAT)
C
      if  (ISTAT.gt.1) then
C
        IERR = max(IERR,ISTAT)
        call ERRSTC(RTNAME,10)
C
      else
C
        DRAD = DHR * 15.D0 * DPI180
C
      endif
C
C
D     IF (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      RETURN
      END
