! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine JDCAL2(DJD,ITD,ITS,IERR)
C
CC    Calculates the Calendar Date out of the Julian Date.
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:37
C
CA  author : KOD        date: 9-MAR-1992 16:50
CU  update : KOD        date: 11-MAR-1992 16:18
CU  update : KOD        date: 11-MAR-1992 16:58
C
CT  status: tested
C
C   general description 
CG
CG  This subroutine calculates the Calendar Date out of the Julian Date
CG  for the years 1950 to 2049. The Calendar Date is contained in the
CG  integers values ITD (YYMMDD) and ITS (msec of the day in UT).
C
C   call_var.          type I/O description 
CP  DJD                 R8  I/? Julian Date
CP  ITD                 I4    O Calendar Date  (YYMMDD)
CP  ITS                 I4    O Universal Time (msec of the day)
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
CI  R_INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description 
CR  JDCAL1              SR      calculates the calendar date
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
      INCLUDE 'R_INCLUDE:IGENL.INC'
C
      REAL*8        DJD
      REAL*4        HFLAG, SEC
      INTEGER*4     IERR, IOS, ISTAT, ITD, ITS, IY, IM, ID, IHR, IMT
      CHARACTER*4   CH4
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'JDCAL2'/
C
D     IF (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR = 0
C
C     check input values:
C
      if (DJD.lt.2433282.5D0 .or. DJD.gt.2469807.5D0) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in Julian Date; < 1950 or > 2049')
      endif
C
C
      if (IERR.lt.2) then
C
        call JDCAL1(DJD,IY,IM,ID,IHR,IMT,SEC,ISTAT)
C
        if  (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        else
          write(CH4,'(I4)') IY
          read(CH4,'(2X,I2)') IY
          ITD = IY * 10000 + IM * 100 + ID
          ITS = (IHR * 3600 + IMT * 60) * 1000 + nint(SEC*1.E3)
        endif
C
      endif
C
D     IF (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      RETURN
      END
