! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine POLRE1(DR,DPHI,DTHETA,DX,DY,DZ,IERR)
C
CC    Converts polar coordinates into rectangular coordinates
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:37
C
CA  author : KOD        date: 19-JUN-1989 18:31
CU  update : KOD        date: 20-MAR-1990 15:08
CU  update : KOD        date: 17-AUG-1992 11:16 (`1.D-6')
C
CT  status: tested
C
C   general description 
CG  Subroutine to convert the polar coordinates (DR,DPHI,DTHETA)
CG  (mathematical notation) into the rectangular coordinates
CG  (DX,DY,DZ).
C
C   call_var.          type I/O description 
CP  DR                  R8  I   radius  (same unit as DX,DY,DZ)
CP  DPHI                R8  I   azimuthal angle  (radians)
CP  DTHETA              R8  I   polar     angle  (radians)
CP  DX                  R8    O x-value (same unit as DX,DY,DZ)
CP  DY                  R8    O y-value (same unit as DX,DY,DZ)
CP  DZ                  R8    O z-value (same unit as DX,DY,DZ)
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        general parameter common block
CI  R_INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description 
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
      INCLUDE 'R_INCLUDE:IGENL.INC'
C
      REAL*8        DR, DPHI, DTHETA, DX, DY, DZ, DST
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'POLRE1'/
C
D     IF (HFLAG(RTNAME,'in: <input_parameters> ').NE.0) THEN
D       WRITE (OUTPT,101,IOSTAT=IOS) !<input_parameters>
D 101   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      IERR=0
C
      if (DR.lt.-1.D-6 .or. DPHI.lt.-1.D-6 .or. DPHI.gt.D2PI+1.D-6 .or.
     $    DTHETA.lt.-1.D-6 .or. DTHETA.gt.DPI+1.D-6) then
        IERR = 1
        call WRERR(RTNAME,IERR,'Error in input parameters')
      endif
C
      DST = dsin(DTHETA)
C
      DX = DR * DST * dcos(DPHI)
      DY = DR * DST * dsin(DPHI)
      DZ = DR * dcos(DTHETA)
C
D     IF (HFLAG(RTNAME,'out: <output_parameters> ').NE.0) THEN
D       WRITE (OUTPT,9901,IOSTAT=IOS) !<output_parameters>
D9901   FORMAT (  )
D       CALL WRFLAG(OUTPT)
D     ENDIF
C
      RETURN
      END
