! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine SMCRT2(NBAND,NBSM,SBSM,NSM,RMS,IERR)
C
CC    Creates small maps of sufficient overlap covering the whole sphere
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:38
C
CA  author : KOD        date: 26-AUG-1992 10:42
CU  update : KOD        date: 26-AUG-1992 10:51
CU  update : KOD        date: 26-AUG-1992 11:20
C
CT  status: not tested
C
C   general description 
CG
CG  Subroutine to split the surface of a sphere into small maps.
CG  These small maps all have the same extent with respect to
CG  the polar angle; there will be two circular polar caps with
CG  identical size and one band with the equator in its middle.
CG  The small maps will be determined so that they fit into the
CG  same `square'.
C
C   call_var.          type I/O description 
CP  NBAND               I4  I   number of bands on the the sphere
CP                              including the equatorial band and
CP                              the polar caps
CP                              ( NBAND  > 0  and  not even )
CP  NBSM                I4    O number of small maps per band
CP  SBSM                R4    O solid angle covered by one small map
CP  NSM                 I4    O total number of small maps
CP  RMS                 R4    O relative mean quadratic deviation
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:ICGENL.INC        
C
C   routines_called    type     description 
CR  WRERR               SR      formats error code in standard form
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:ICGENL.INC'
C
      INTEGER*4     IERR ,IOS, NBAND, NBSM(NBAND), NSM, N, I, NUMB
      REAL*4        HFLAG, PDIFF, PID2, PSIZE, PI2, ANG1, ANG2,
     &              TSIZE, SBSM(NBAND), RMS, H, SIZEM, TDIFF
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'SMCRT2'/
C
      PI2  = 2.0 * PI
      PID2 = 0.5 * PI
C
      IERR = 0
C
C     check input value:
C
      if (NBAND.le.0 .or. mod(NBAND,2).eq.0) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input parameter')
      endif
C
C
      if (IERR.lt.2) then
C
        if (NBAND.eq.1) then
C
          NBSM(1) = 1
          SBSM(1) = 2.0 * PI2
          NSM = 1
C
        else
C
          N = NBAND / 2
C
C         determine extent in polar angle:
C
          PDIFF = PI / real(NBAND-1)
C
          NBSM(NBAND) = 1
C
C         calculate the size of the polar cap:
C
          PSIZE = PI2 * ( 1.0 - cos (0.5 * PDIFF) )
          SBSM(NBAND) = PSIZE
C
C
C         find the number of sm per band with approx.the same max extent
C
          do I = 1, N
C
C           calculate the length of the larger small circle
C           defining the boundary of the band:
C
            ANG1 = (real(I) - 1.5) * PDIFF
            ANG2 = ANG1 + PDIFF
C
            TSIZE = PI2 * ( sin(ANG2) - sin(ANG1) )
            TDIFF = PI2 * cos(ANG1)
C
C           find the number of small maps:
C
            NUMB = int(TDIFF / PDIFF)
            if (real(NUMB)*PDIFF.lt.TDIFF) NUMB = NUMB + 1
C
            NBSM(N+I) = NUMB
            SBSM(N+I) = TSIZE / real(NUMB)
C
          end do
C
C         copy upper part of the sphere to lower part:
C
          do I = 1, N
            NBSM(I) = NBSM(NBAND+1-I)
            SBSM(I) = SBSM(NBAND+1-I)
          end do
C
C         calculate the total number of small maps:
C
          NSM = 0
          do I = 1, NBAND
            NSM = NSM + NBSM(I)
            H = H + real(NBSM(I)) * SBSM(I)
          end do
C
C         calculate the mean quadratic deviation:
C
          SIZEM = 2.0 * PI2 / real (NSM)
C
          RMS = 0.0
          do I = 1, NBAND
            H = (SBSM(I)-SIZEM)
            RMS = RMS + real(NBSM(I)) * H * H
          end do
          RMS = sqrt(RMS) / (real(NSM) * SIZEM)
C
        endif
C
      endif
C
      RETURN
      END
