! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      SUBROUTINE ZONCEN(NZONE,NLAT,NLON,NOMRA,NOMDE,IERR)
C
CC    Calculates the field center from the lat/long zone number/counter
C
C************************ FFORM VERSION 1.2 ************  4-DEC-98 16:38
C
CA  author : KOD        date: 14-JUN-1994
CU  update : GRU        date: 4-AUG-1994 10:28
C
CT  status: not tested
C
C   general description 
CG  Subroutine to calculate the field center from the latitude zone
CG  number and longitude zone counter.
C
C   call_var.          type I/O description 
CP  NZONE               I4  ?/? number of zones on the the sphere
CP                              including the equatorial zone and
CP                              the polar caps
CP                              ( NZONE > 0  and  not even )
CP  NLAT                I4  ?/? latitude zone number
CP  NLON                I4  ?/? longitude zone counter
CP  NOMRA               I4    O RA  of center of field [0.5 arcsec]
CP  NOMDE               I4    O DEC of center of field [0.5 arcsec]
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description 
CI  R_INCLUDE:IGENL.INC         
C
C   routines_called    type     description 
CR  ERRSTC              SR      continue error stack for one level
CR  SMCEN3              SR      
C
C   extensions/system calls     description 
CX 
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
      INCLUDE 'R_INCLUDE:IGENL.INC'
c
      REAL*8        DALPH0, DDELT0
      INTEGER*4     NZONE, NLAT, NLON, NOMRA, NOMDE, IERR, ISTAT
      LOGICAL       LCEN
      CHARACTER*8   RTNAME
c
      DATA          RTNAME /'ZONCEN'/
c
c     R.A. = 0.0 is at the field boundary:
c
      PARAMETER ( LCEN = .FALSE. )
c
      IERR = 0
c
      CALL SMCEN3(NZONE,NLAT,NLON,LCEN,DALPH0,DDELT0,ISTAT)
C
      IF (ISTAT.NE.0) THEN
        IERR = MAX(IERR,ISTAT)
        CALL ERRSTC(RTNAME,10)
      ELSE
        NOMRA = NINT(DALPH0*7200.D0)
        NOMDE = NINT(DDELT0*7200.D0)
      ENDIF
C
      RETURN
      END
