! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine REPOL1(DX,DY,DZ,DR,DPHI,DTHETA)
C
CC    Converts rectangular coordinates into polar coordinates
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:10
C
CA  author : KOD        date: 15-JUN-1989 18:31
CU  update : KOD        date: 20-MAR-1990 15:09
C
CT  status: tested
C
C   general description
CG  Subroutine to convert the rectangular coordinates (DX,DY,DZ)
CG  into the polar coordinates (DR,DPHI,DTHETA) - mathematical
CG  notation.
C
C   call_var.          type I/O description
CP  DX                  R8  I   x-value
CP  DY                  R8  I   y-value
CP  DZ                  R8  I   z-value
CP
CP  DR                  R8    O radius   (same unit as DX,DY,DZ)
CP  DPHI                R8    O azimuthal angle  (radians)
CP  DTHETA              R8    O  polar    angle  (radians)
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DX, DY, DZ, DR, DPHI, DTHETA, DH
      REAL*4        HFLAG
      INTEGER*4     IOS
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'REPOL1'/
C
      DR = dsqrt(DX*DX+DY*DY+DZ*DZ)
C
      if (DR.eq.0.0D0) then
        DPHI   = 0.0D0
        DTHETA = 0.0D0
      else
        DTHETA = dacos(DZ/DR)
        DH = dsqrt(DX*DX+DY*DY)
        if (DH.eq.0.0D0) then
          DPHI = 0.0D0
        else
          DPHI = dasin(DY/DH)
          if (DX  .lt. 0.0D0) DPHI = DPI  - DPHI
          if (DPHI.lt. 0.0D0) DPHI = DPHI + D2PI
        endif
      endif
C
      RETURN
      END
