! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine RESVAL(DXMIN,DXMAX,DXOLD,DXNEW,IERR)
C
CC    'Resets' periodic variables to their basic interval
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:10
C
CA  author : KOD        date: 19-JUL-1989 18:31
CU  update : KOD        date: 20-MAR-1990 15:10
C
CT  status: tested
C
C   general description
CG  Subroutine to 'reset' the values of periodically defined
CG  variables to their basic interval.
C
C   call_var.          type I/O description
CP  DXMIN               R8  I   left  boundary of basic interval
CP  DXMAX               R8  I   right boundary of basic interval
CP
CP  DXOLD               R8  I   value before resetting
CP  DXNEW               R8    O value after  resetting
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DXMIN, DXMAX, DXOLD, DXNEW, DDIFF, DH
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'RESVAL'/
C
      IERR = 0
C
      if (DXMIN.ge.DXMAX) then
        IERR = 2
        call WRERR(RTNAME,IERR,'Error in input parameters DXMIN,DXMAX')
      endif
C
      if (IERR.lt.2) then
        DDIFF = DXMAX - DXMIN
        DH = (DXOLD-DXMIN) / DDIFF
        DH = DH - DINT(DH)
        if (DH.lt.0.D0) DH = DH + 1.D0
        DXNEW = DXMIN + DH * DDIFF
      endif
C
      RETURN
      END
