! Copyright (C) 2019-2021:
!   Max Planck Institut fuer extraterrestrische Physik, Leibniz Institute for Astrophysics Potsdam (AIP)
!
! This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License as published by the Free Software Foundation; either
! version 2 of the License, or (at your option) any later version.
!
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
! General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this library; if not, write to the Free Software
! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
! USA, or see https://www.gnu.org/licenses/.
!

      subroutine TRPOL1(DALPH0,DDELT0,DALPHA,DDELTA,DAPOL,DDPOL)
C
CC    Transforms equatorial coordinates to the polar cap
C
C************************ FFORM VERSION 1.1 ************ DD-MMM-YY HH:MM
C
CA  author : KOD        date:  9-AUG-1990 14:57
C
CT  status: not tested
C
C   general description:
CG
C
C   call_var.          type I/O description
CP
CP  DALPH0              R8  I   Right Ascension of reference  (radians)
CP  DDELT0              R8  I   Declination     of reference  (radians)
CP
CP  DALPHA              R8  I   Right Ascension to be transformed (rad)
CP  DDELTA              R8  I   Declination     to be transformed (rad)
CP
CP  DAPOL               R8    O transformed Right Ascension   (radians)
CP  DDPOL               R8    O transformed Declination       (radians)
CP
CP  (ierr)              I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block_name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DALPH0, DDELT0, DALPHA, DDELTA, DAPOL, DDPOL,
     &              D1, D2, D3, DPH1, DTH1, DPH2, DTH2
      REAL*4        HFLAG
      INTEGER*4     IERR, ISTAT
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'TRPOL1'/
C
      IERR = 0
C
      D1 =  DPID2 + DALPH0
      D2 =  DPID2 - DDELT0
      D3 = -DPID2 - DALPH0
C
      DPH1 = DALPHA
      DTH1 = DPID2 - DDELTA
C
      CALL EULER1(D1,D2,D3,DPH1,DTH1,DPH2,DTH2,ISTAT)
C
      DAPOL= DPH2
      DDPOL= DPID2 - DTH2
C
C
      RETURN
      END
