      subroutine BACOR1(DJD,DJD0,DALPHA,DDELTA,DTSEC,IERR)
C
CC    Calculates the barycentric correction for a given object and date
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:43
C
CA  author : KOD        date: 12-OCT-1989 17:24
CU  update : KOD        date: 28-MAR-1990 19:20
CU  update : KOD        date: 22-OCT-1991 11:33
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the time correction which has to be
CG  ADDED to reduce the photon arrival times measured at the
CG  centre of the earth to the center of the sun - not to the solar
CG  system barycenter ! @@@@@@
CG
CG  This subroutine can be used for converting the pulse arrival
CG  times at any point on earth or in a low-earth orbit (h < 1000 km)
CG  if an accuracy of 25 msec is sufficient.
CG
CG  Without this correction the difference between topocentric and
CG  barycentric photon arrival times can became as large as 500 sec.
C
C   call_var.          type I/O description
CP  DJD                 R8  I   Julian Date for the baryc. correction
CP  DJD0                R8  I   Julian Date defining the equinox
CP
CP  DALPHA              R8  I   right ascension at DJD0   (radians)
CP  DDELTA              R8  I   declination at DJD0       (radians)
CP
CP  DTSEC               R8    O time correction           (seconds)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  CSUN02              SR      calculates rectangular sun coordinates
CR  POLRE1              SR      converts polar into rectang. coord.
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DJD, DJD0, DALPHA, DDELTA, DTSEC, DX, DY, DZ,
     &              DL, DB, DR, DTH, DX0, DY0, DZ0, DF, DJ, DJ0, DA
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      CHARACTER*8   RTNAME
C
      PARAMETER ( DF = 499.004D0 )
C
      DATA          RTNAME /'BACOR1'/
C
      IERR = 0
C
      if (DALPHA.lt.0.d0 .or. DALPHA.gt.D2PI .or.
     &    abs(DDELTA).gt.DPID2) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input coordinates')
      endif
C
      if (IERR.lt.2) then
C
C       calculate the rectangular coordinates of the sun:
C
        DJ  = DJD
        DJ0 = DJD0
        call CSUN02(DJ,DJ0,DX,DY,DZ,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      endif
C
      if (IERR.lt.2) then
C
C       calculate the rectangular coordinates of the star:
C
        DR = 1.D0
        DTH = DPID2 - DDELTA
        DA = DALPHA
        call POLRE1(DR,DA,DTH,DX0,DY0,DZ0,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,20)
        endif
C
      endif
C
      if (IERR.lt.2) then
C
        DR = DX * DX0 + DY * DY0 + DZ * DZ0
        DTSEC = -DR * DF
C
      endif
C
      RETURN
      END
