      subroutine CHDAT3(IY,IM,ID,IHR,IMT,SEC,LCHECK,CHDAT,IERR)
C
CC    Produces a string of the form 'YYYY.MM.DD / HH:MM:SS.SS'
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:52
C
CA  author : KOD        date: 15-NOV-2016
C
CT  status: tested
C
C   general description
CG
CG  Subroutine to produce a string of the form
CG  'YYYY.MM.DD / HH:MM:SS.SS'  (Maximum resolution: 10 msec).
CG  There will be a rough check on the validity of the given date;
CG  a detailed check is also possible (see LCHECK).
C
C   call_var.          type I/O description
CP  IY                  I4  I   year         (-999 .. +9999)
CP  IM                  I4  I   month        (1 .. 12)
CP  ID                  I4  I   day of month (1 .. 28,29,30,31)
CP  IHR                 I4  I   hours        (0 .. 23)
CP  IMT                 I4  I   minutes      (0 .. 59)
CP  SEC                 R4  I   seconds      (0.0 .. 59.999...)
CP
CP  LCHECK              L4  I   extended input check if LCHECK=.true.
CP
CP  CHDAT               C   I/O string containing the calendar date
CP                              'YYYY' to 'YYYY.MM.DD / HH:MM:SS.SS'
CP
CP                               possible lengths 'L' of CHDAT :
CP                               L = 19 : 'yyyy-mm-ddThh:mm:ss'
CP
CP                               The values for the year, month
CP                               and day will not be rounded,
CP                               the values for the hour, minute
CP                               and second will be rounded.
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  JDCAL1              SR      Julian Date to Calendar Date
CR  CALJD1              SR      Calendar Date to Julian Date
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DJD
      REAL*4        HFLAG, SEC, F, FSEC, H, SEC1
      INTEGER*4     IERR ,IOS, IY, IM, ID, IHR, IMT, N, NDIG, ISEC,
     &              ISEC1, ISEC2, IY1, IM1, ID1, IHR1, IMT1,
     &              I1, I2, ISTAT
      LOGICAL*4     LCHECK, LCHK
      CHARACTER*3   CHDIG
      CHARACTER*(*) CHDAT
      CHARACTER*70  CHFMT
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CHDATE'/
C
      IERR = 0
C
      N = 19
C
C     (rough) check for meaningful date:
c
      if (IY .lt.-999 .or.  IY.gt.9999  .or.
     &    IM .lt.1    .or.  IM.gt.12    .or.
     &    ID .lt.1    .or.  ID.gt.31    .or.
     &    IHR.lt.0    .or.  IHR.gt.23   .or.
     &    IMT.lt.0    .or.  IMT.gt.59   .or.
     &    SEC.lt.0.0  .or.  SEC.gt.60.0) then
C
        ISTAT = 2
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in input parameters IY .. SEC')
C
      endif
C
C
C     precise check for valid date:
C
      if (IERR.lt.2) then
C
C       copy input parameters:
C
        IY1  = IY
        IM1  = IM
        ID1  = ID
        IHR1 = IHR
        IMT1 = IMT
        SEC1 = SEC
C
        if (LCHECK) then
C
          LCHK = LCHECK
          call CALJD1(IY1,IM1,ID1,IHR1,IMT1,SEC1,LCHK,DJD,ISTAT)
C
          if (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,10)
          endif
C
        endif
C
        SEC1 = SEC-1.E-6
C
C       round values:
C
        NDIG  = min( max(N-22,0), 3 )
        F     = real( 10**NDIG )
        ISEC  = nint( SEC1*F )
        FSEC  = real( ISEC ) / F
        ISEC1 = int( FSEC )
        ISEC2 = ISEC - ISEC1 * 10**NDIG
C
C
C       increase minutes:
C
        if ( (ISEC1.ge.60) .or.
     &       (N.le.18 .and. SEC1.gt.30.0) ) then
          SEC1  = 0.0
          ISEC1 = 0
          ISEC2 = 0
          IMT1 = IMT1 + 1
        endif
C
C
C       increase hours:
C
        if ( (IMT1.ge.60) .or.
     &       (N.le.15 .and.
     &        (IMT1.gt.30 .or. (IMT1.eq.30 .and. SEC1.gt.0.0))) ) then
          SEC1  = 0.0
          ISEC1 = 0
          ISEC2 = 0
          IMT1 = 0
          IHR1 = IHR1 + 1
        endif
C
C
C       increase the day:
C
        if (IHR1.eq.24) then
C
          IHR1 = 0
C
          LCHK=.true.
          call CALJD1(IY1,IM1,ID1,IHR1,IMT1,SEC1,LCHK,DJD,ISTAT)
C
          if (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,20)
          endif
C
          if (IERR.lt.2) then
            DJD = DJD + 1.D0
            call JDCAL1(DJD,IY1,IM1,ID1,IHR1,IMT1,SEC1,ISTAT)
C
            if (ISTAT.gt.1) then
              IERR = max(IERR,ISTAT)
              call ERRSTC(RTNAME,30)
            endif
C
          endif
        endif
C
C
C       assign result to CHDAT:
C
        write(chdat,'(i4,5(a,i2))')
     &        iy1,'-',im1,'-',id1,'T',ihr1,':',imt1,':',isec1
C
      endif
C
      RETURN
      END
