      subroutine CHDEG2(DRAD,CHDG,IERR)
C
CC    Converts radians into degrees and writes a string 'DDD:MM.MMMMM'
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:52
C
CA  author : KOD        date: 25-AUG-1989 14:41
CU  update : KOD        date: 28-MAR-1990 19:10
C
CT  status: tested
C
C   general description
CG  Subroutine to convert radians into a degrees and write a string
CG  of the form 'DDD:MM.MMMMM'
C
C   call_var.          type I/O description
CP  DRAD                R8  I   angle to be converted (rad,-pi/2..2*pi)
CP
CP  CHDG                C   I/O string containing the degrees
CP                              'DDD:MM.MMMMM'
CP
CP                               possible lengths 'L' of CHDG :
CP                               L =  3 : 'DDD'
CP                               L =  6 : 'DDD:MM'
CP                               L =  8 : 'DDD:MM.M'
CP                               L =  9 : 'DDD:MM.MM'
CP                               L = 10 : 'DDD:MM.MMM'
CP                               L = 11 : 'DDD:MM.MMMM'
CP                               L = 12 : 'DDD:MM.MMMMM'
CP
CP                               In each case the values
CP                               will be rounded appropriately;
CP                               the value of DDD must be greater
CP                               than -99 and less than 999.
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  CNVDMS              SR      splits decimal degrees
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DRAD, DDG, DDGABS
      REAL*4        HFLAG, F, RMIN, RSEC
      INTEGER*4     IERR ,IOS, IDG, IMIN, N, NDIG, IMIN1, ISTAT
      LOGICAL*4     LUNIT, LPLUS, LH
      CHARACTER*3   CHDIG
      CHARACTER*35  CHFMT
      CHARACTER*(*) CHDG
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CHDEG2'/
C
      IERR = 0
C
C     initialize values:
C
      N = len(CHDG)
      DDG = DRAD * D180PI
      LUNIT = (DDG.ge.-90.D0 .and. DDG.lt.360.D0)
C
C     check input values:
C
      ISTAT = 1
      if (N.eq.3 .or. N.eq.6 .or. (N.ge.8 .and. N.le.12))
     &  ISTAT = 0
      if (ISTAT.ne.0) then
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in length of CHDG')
        N = min(N,12)
      endif
C
      ISTAT = 0
      if (DDG.lt. -90.D0 .or. DDG.ge. 360.D0) ISTAT = 1
      if (DDG.le.-100.D0 .or. DDG.ge.1000.D0) ISTAT = 2
C
      if (ISTAT.ne.0) then
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in the input parameter DDG')
      endif
C
C
      if (IERR.lt.2) then
C
C       store sign:
C
        LPLUS = (DDG.ge.0.D0)
        DDGABS = dabs(DDG)
C
C       extract hours, minutes and seconds:
C
        call CNVDMS(DDGABS,LH,IDG,IMIN,RSEC,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        else
          RMIN = RSEC / 60.0
        endif
C
      endif
C
C
      if (IERR.lt.2) then
C
C       round values:
C
        NDIG = max(N-7,0)
        F = real(10**NDIG)
        IMIN1 = nint(RMIN*F)
C
        if ( (IMIN1.eq.10**NDIG) .or.
     &       (N.le.6 .and. (IMIN1.gt.0.5*F .or. RMIN.gt.0.5)) ) then
          RMIN = 0.0
          IMIN1 = 0
          IMIN = IMIN + 1
        endif
C
        if ( (IMIN.ge.60) .or.
     &       (N.eq.3 .and.
     &        (IMIN.gt.30 .or. (IMIN.eq.30 .and. RMIN.gt.0.0))) ) then
          RMIN = 0.0
          IMIN = 0
          IDG = IDG + 1
        endif
C
        if (LUNIT .and. IDG.ge.360) IDG = IDG - 360
C
        if (.not.LPLUS) IDG = -IDG
C
C       assign result to CHDG:
C
        if (N.eq.3) write(CHDG,'(I3.1)') IDG
        if (N.eq.6) write(CHDG,'(I3.1,'':'',I2.2)') IDG,IMIN
        if (N.ge.8) then
           write(CHDIG,'(I1,''.'',I1)') NDIG,NDIG
           CHFMT = '(I3.1,'':'',I2.2,''.'',I' // CHDIG // ')'
           write(CHDG,CHFMT) IDG,IMIN,IMIN1
        endif
C
        if (.not.LPLUS .and. IDG.eq.0) CHDG(2:2)='-'
C
      endif
C
      RETURN
      END
