      subroutine CHHR2(DRAD,CHHR,IERR)
C
CC    Converts radians into hours and writes a string 'HH:MM.MMMMM'
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:17
C
CA  author : KOD        date: 28-AUG-1989 15:04
CU  update : KOD        date: 28-MAR-1990 19:13
C
CT  status: tested
C
C   general description
CG  Subroutine to convert radians into a hours and write a string
CG  of the form 'HH:MM.MMMMM'
C
C   call_var.          type I/O description
CP  DRAD                R8  I   angle to be converted (rad,0..2*pi)
CP
CP  CHHR                C   I/O  string containing the hours
CP                              'HH:MM.MMMMM'
CP
CP                               possible lengths 'L' of CHHR :
CP                               L =  2 : 'HH'
CP                               L =  5 : 'HH:MM'
CP                               L =  7 : 'HH:MM.M'
CP                               L =  8 : 'HH:MM.MM'
CP                               L =  9 : 'HH:MM.MMM'
CP                               L = 10 : 'HH:MM.MMMM'
CP                               L = 11 : 'HH:MM.MMMMM'
CP
CP                               In each case the values
CP                               will be rounded appropriately;
CP                               the value of HH must be positive
CP                               (or zero) and less than 100.
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  CNVDMS              SR      splits decimal degrees
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DRAD, DHR
      REAL*4        HFLAG, RMIN, RSEC, F
      INTEGER*4     IERR ,IOS, IHR, IMIN, N, NDIG, IMIN1, ISTAT
      LOGICAL*4     LUNIT, LH
      CHARACTER*3   CHDIG
      CHARACTER*33  CHFMT
      CHARACTER*(*) CHHR
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CHHR2 '/
C
      IERR = 0
C
C     initialize values:
C
      N = len(CHHR)
      DHR = DRAD * 24.D0 / D2PI
      LUNIT = (DHR.ge.0.D0 .and. DHR.lt.24.D0)
C
C     check input values:
C
      ISTAT = 1
      if (N.eq.2 .or. N.eq.5 .or. (N.ge.7 .and. N.le.11))
     &  ISTAT = 0
      if (ISTAT.ne.0) then
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in length of CHHR')
        N = min(N,11)
      endif
C
      ISTAT = 0
      if (DHR.ge.24.D0) ISTAT = 1
      if (DHR.lt.0.D0 .or. DHR.ge.100.D0) ISTAT = 2
C
      if (ISTAT.ne.0) then
        IERR = max(IERR,ISTAT)
        call WRERR(RTNAME,IERR,'Error in the input parameter DHR')
      endif
C
C
      if (IERR.lt.2) then
C
C       extract hours, minutes and seconds:
C
        call CNVDMS(DHR,LH,IHR,IMIN,RSEC,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        else
          RMIN = RSEC / 60.0
        endif
      endif
C
C
      if (IERR.lt.2) then
C
C       round values:
C
        NDIG = max(N-6,0)
        F = real(10**NDIG)
        IMIN1 = nint(RMIN*F)
C
        if ( (IMIN1.eq.10**NDIG) .or.
     &       (N.le.5 .and. (IMIN1.gt.0.5*F .or. RMIN.gt.0.5)) ) then
          RMIN = 0.0
          IMIN1 = 0
          IMIN = IMIN + 1
        endif
C
        if ( (IMIN.ge.60) .or.
     &       (N.eq.2 .and.
     &        (IMIN.gt.30 .or. (IMIN.eq.30 .and. RMIN.gt.0.0))) ) then
          RMIN = 0.0
          IMIN = 0
          IHR = IHR + 1
        endif
C
        if (LUNIT .and. IHR.ge.24) IHR = IHR - 24
C
C       assign result to chhr:
C
        if (N.eq.2) write(CHHR,'(I2.2)') IHR
        if (N.eq.5) write(CHHR,'(I2.2,'':'',I2.2)') IHR,IMIN
        if (N.ge.7) then
           write(CHDIG,'(I1,''.'',I1)') NDIG,NDIG
           CHFMT = '(I2.2,'':'',I2.2,''.'',I' // CHDIG // ')'
           write(CHHR,CHFMT) IHR,IMIN,IMIN1
        endif
C
      endif
C
      RETURN
      END
