      subroutine CMOON2(DJD,LMEAN,DALPHA,DDELTA,DDIST,IERR)
C
CC    Calculates the equ. coordinates and the distance of the moon
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:54
C
CA  author : KOD        date: 05-SEP-1989 16:15
CU  update : KOD        date: 28-MAR-1990 19:50
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the equatorial coordinates and the
CG  distance of the moon, according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.147-153 .
CG
CG  To calculate the TRUE position, use the MEAN obliquity of the
CG  ecliptic (normal case);
CG  for the APPARENT position (affected by aberration and nutation)
CG  use the TRUE obliquity.
CG  In the equatorial coordinates shall refer to a standard equinox
CG  (1950, 2000, ...), the obliquity of the ecliptic for this epoch
CG  should be used.
CG  (Jean Meeus, 'Astronomical Formulae for Calculators',
CG                third edition, 1985, p.43-44)
CG
CG  Accurracy: 10 arcsec in position, 25 km in distance
C
C   call_var.          type I/O description
CP  DJD                 R8  I   Julian Date ( Ephemeris time !)
CP
CP  LMEAN               L4  I   mean or true obliquity of the ecliptic:
CP                                LMEAN = .true.  : mean obliquity
CP                                LMEAN = .false. : true obliquity
CP
CP  DALPHA              R8    O right ascension      (radians)
CP  DDELTA              R8    O declination          (radians)
CP  DDIST               R8    O distance             (km)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
C
C   routines_called    type     description
CR  CMOON1              SR      calculates ecl. position of the moon
CR  EQUECL              SR      converts ecl. to equatorial coorindates
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      LOGICAL*4     LMEAN, LDIR, LMN
      REAL*8        DJD, DALPHA, DDELTA, DDIST, DLECL, DBECL, DPRLX, DJ,
     &              DA, DD
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CMOON2'/
C
      IERR = 0
C
      if (DJD.lt.0.D0 .or. DJD.gt.3.D6) then
        IERR = 2
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
      if (IERR.lt.2) then
C
        DJ = DJD
        call CMOON1(DJ,DLECL,DBECL,DPRLX,ISTAT)
C
        if (ISTAT.gt.1) then
C
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
C
        else
C
          LDIR = .false.
          LMN = LMEAN
          call EQUECL(DJ,LMN,LDIR,DLECL,DBECL,DA,DD,ISTAT)
C
          if (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,20)
          else
            DALPHA = DA
            DDELTA = DD
            DDIST = 6378.14D0 / sin (DPRLX)
          endif
C
        endif
C
      endif
C
      RETURN
      END
