      subroutine CPREC2(LDIR,DLOLD,DBOLD,DLNEW,DBNEW,IERR)
C
CC    Converts equatorial coordinates between 1950.0 and 2000.0
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:55
C
CA  author : KOD        date: 28-SEP-1989 17:10
CU  update : KOD        date: 28-MAR-1990 20:05
C
CT  status: tested
C
C   general description
CG  Subroutine to convert the equatorial coordinates between
CG  the equinox 1950.0 and 2000.0, according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.65,66.
CG
CG  Notes: the effect of the proper motion must be calculated BEFORE
CG         converting the coordinates to another epoch.
CG
C
C   call_var.          type I/O description
CP  LDIR                L4  I   direction of the conversion:
CP                                LDIR = .true.  : 1950.0 --> 2000.0
CP                                LDIR = .false. : 1950.0 <-- 2000.0
CP
CP  DLOLD               R8  I   old longitude  (radians)
CP  DBOLD               R8  I   old latitude   (radians)
CP
CP  DLNEW               R8    O new longitude  (radians)
CP  DBNEW               R8    O new latitude   (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  CPREC1              SR      converts equ.coord. for precession
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DLOLD, DBOLD, DLNEW, DBNEW, DJD1, DJD2, DL1, DB1,
     &              DL2, DB2
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      LOGICAL       LDIR
      CHARACTER*8   RTNAME
C
C     Julian Day for equinox 1950.0:
      PARAMETER ( DJD1 = 2433282.423D0 )
C
C     Julian Day for equinox 2000.0:
      PARAMETER ( DJD2 = 2451545.000D0 )
C
      DATA          RTNAME /'CPREC2'/
C
      IERR = 0
C
      DL1 = DLOLD
      DB1 = DBOLD
C
      if (LDIR) then
         call CPREC1(DJD1,DJD2,DL1,DB1,DL2,DB2,ISTAT)
      else
         call CPREC1(DJD2,DJD1,DL1,DB1,DL2,DB2,ISTAT)
      endif
C
      if  (ISTAT.gt.1) then
        IERR = max(IERR,ISTAT)
        call ERRSTC(RTNAME,10)
      else
        DLNEW = DL2
        DBNEW = DB2
      endif
C
C
      RETURN
      END
