      subroutine CPROP1(DJD0,DJD,DLOLD,DBOLD,DLP,DBP,DLNEW,DBNEW,IERR)
C
CC    Calculates the change of the equ. coordinates due to proper motion
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:55
C
CA  author : KOD        date: 26-SEP-1989 16:50
CU  update : KOD        date: 20-MAR-1990 14:42
CU  update : KOD        date: 17-AUG-1992 10:08 (`1.D-6')
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the effect of proper motion on the
CG  equatorial coordinates. This effect has to be taken into
CG  account BEFORE converting the coordinates to another epoch,
CG  according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.66 .
C
C   call_var.          type I/O description
CP  DJD0                R8  I   Julian Date for the initial epoch
CP  DJD                 R8  I   Julian Date for the current epoch
CP
CP  DLOLD               R8  I   old longitude  (radians)
CP  DBOLD               R8  I   old latitude   (radians)
CP
CP  DLP                 R8  I   annual proper motion in R.A. (radians)
CP  DBP                 R8  I   annual proper motion in Dec. (radians)
CP
CP  DLNEW               R8    O new longitude  (radians)
CP  DBNEW               R8    O new latitude   (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DJD0, DJD, DLOLD, DBOLD, DLP, DBP, DLNEW, DBNEW, DT
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CPROP1'/
C
      IERR = 0
C
      if (DLOLD.lt.-1.D-6 .or. DLOLD.gt.D2PI+1.D-6) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,'Warning: unusual input value for DLOLD')
      endif
C
      if (dabs(DBOLD).gt.DPID2+1.D-6) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in the input parameter DBOLD')
      endif
C
      if ( max( abs(DLP*cos(DBOLD)), abs(DBP) ).gt.1.D-4) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input parameters DLP, DBP')
      endif
C
      if (min(DJD0,DJD).lt.0.D0 .or. max(DJD0,DJD).gt.3.D6) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
      if (IERR.lt.2) then
        DT = (DJD - DJD0) / 365.242199D0
        DLNEW = DLOLD + DT * DLP
        DBNEW = DBOLD + DT * DBP
      endif
C
C
      RETURN
      END
