      subroutine CPSAB1(DJD,DLOLD,DBOLD,LDIR,DLNEW,DBNEW,IERR)
C
CC  corrects ecliptical positions for the effect of aberration
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:55
C
CA  author : KOD        date: 06-MAR-1991 14:45
CU  update : KOD        date: 22-OCT-1991 10:47
CU  update : KOD        date: 25-OCT-1991 14:40
C
CT  status: not tested
C
C   general description
CG
CG  Subroutine to correct ecliptical positions for the effect of
CG  (annual) aberration. It can be applied in both directions (see
CG  LDIR). Here the term 'uncorrected' specifies the true position
CG  while 'corrected' refers to the apparent position.
CG  The method applied has been described by F.Schmeidler, in:
CG    G.D.Roth: `Handbuch fuer Sternfreunde' (I), p.305-306,
CG    (Springer Verlag, vierte Auflage)
CG  It provides only an approximate correction since the Earth is
CG  assumed to orbit the sun in a circle with constant velocity.
CG  ||| This method is not applicable to the ecliptical poles |||
CG
C
C   call_var.          type I/O description
CP
CP  DJD                 R8  I   Julian Date for the correction
CP
CP  DLOLD               R8  I   old ecl. longitude  (radians)
CP  DBOLD               R8  I   old ecl. latitude   (radians)
CP
CP  LDIR                L   I   direction of the correction:
CP                               = .true. :  uncorrected ---> corrected
CP                               = .false.:  uncorrected <--- corrected
CP
CP  DLNEW               R8    O new longitude  (radians)
CP  DBNEW               R8    O new latitude   (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  CSUN01              SR      calculates the ecl. coord. of the sun
CR  DRADRS              R8      'resets' radians
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DJD, DLOLD, DBOLD, DLNEW, DBNEW, DLONG, DDIST,
     &              DC, DLDIFF, DL, DB, DH, DRADRS
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      LOGICAL       LDIR
      CHARACTER*8   RTNAME
C
C     constant for aberration (radians):
C
      PARAMETER   ( DC = 9.93674D-5 )
C
      DATA          RTNAME /'CPSAB1'/
C
      IERR = 0
C
      if (DLOLD.lt.0.D0 .or. DLOLD.gt.D2PI) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,'Warning: unusual input value for DLOLD')
      endif
C
      if (dabs(DBOLD).gt.DPID2) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in the input parameter DBOLD')
      endif
C
      if (DJD.lt.0.D0 .or. DJD.gt.3.D6) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
C
      if (IERR.lt.2) then
C
C       calculate the ecliptical longitude of the sun:
C
        call CSUN01(DJD,.true.,DLONG,DDIST,ISTAT)
C
        if (ISTAT.ne.0) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,IERR)
        endif
C
      endif
C
C
      if (IERR.lt.2) then
C
        DLDIFF = DLOLD - DLONG
C
        DH = dcos(DBOLD)
        if (dabs(DH).lt.1.D-6) DH = dsign(1.D-6,DH)
C
        DL = -DC * dcos(DLDIFF) / DH
        DB =  DC * dsin(DLDIFF) * dsin(DBOLD)
C
        if (LDIR) then
          DLNEW = DRADRS ( DLOLD + DL )
          DBNEW = DBOLD + DB
        else
          DLNEW = DRADRS ( DLOLD - DL )
          DBNEW = DBOLD - DB
        endif
C
        if (dabs(DBNEW).gt.DPID2) then
          IERR = max(IERR,2)
          call WRERR(RTNAME,IERR,
     &        'The method used is not applicable for the ecl. poles')
          DLNEW = DRADRS ( DLNEW + DPI )
          DBNEW = dsign(DPI-dabs(DBNEW),DBNEW)
        endif
C
      endif
C
C
      RETURN
      END
