      subroutine CPSAB2(DVX,DVY,DVZ,LDIR,DXOLD,DYOLD,DZOLD,
     &                  DXNEW,DYNEW,DZNEW,ISTAT)
C
CC  corrects positions for the effect of (non-relativistic) aberration
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:55
C
CA  author : KOD        date: 22-OCT-1991 10:47
CU  update : KOD        date: 25-OCT-1991 15:19
C
CT  status: not tested
C
C   general description
CG
CG  Subroutine to correct positions for the effect of (non-relativistic)
CG  aberration. It can be applied in both directions (see LDIR).
CG  All positions and velocities refer to a rectangular coordinate
CG  system which can be chosen arbitrarily but must be used in a
CG  consistent way. The velocities have to be specified in units of
CG  the speed of light. For the positions unit vectors should/will
CG  be used.
C
C   call_var.          type I/O description
CP
CP  DVX                 R8  I   velocity of the observer in x-direction
CP  DVY                 R8  I   velocity of the observer in y-direction
CP  DVZ                 R8  I   velocity of the observer in z-direction
CP
CP  LDIR                L   I   direction of the correction:
CP                               = .true. :  true pos. --> apparent pos.
CP                               = .false.:  true pos. <-- apparent pos.
CP
CP  DXOLD               R8  I   x-component of the original position
CP  DYOLD               R8  I   y-component of the original position
CP  DZOLD               R8  I   z-component of the original position
CP
CP  DXNEW               R8    O x-component of the resulting position
CP  DYNEW               R8    O y-component of the resulting position
CP  DZNEW               R8    O z-component of the resulting position
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DVX, DVY, DVZ, DXOLD, DYOLD, DZOLD, DXNEW, DYNEW,
     &              DZNEW, DH
      REAL*4        HFLAG
      INTEGER*4     IERR, IOS, ISTAT
      LOGICAL       LDIR
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'CPSAB2'/
C
C
      IERR = 0
C
      DH = dmax1(dabs(DVX),dabs(DVY),dabs(DVZ))
C
      if (DH.gt.1.D0) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in velocity')
      endif
C
      if (DH.gt.0.1D0) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,
     &      'Warning: correction for aberration is non-relativistic')
      endif
C
      DH = DXOLD * DXOLD + DYOLD * DYOLD + DZOLD * DZOLD
C
      if (DH.eq.0.D0) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in position')
      endif
C
      if (dabs(DH-1.D0).gt.1.D-3) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,
     &      'Warning: Position is not specified by a unit vector')
      endif
C
C
      if (IERR.lt.2) then
C
        DH = 1.D0 / DH
C
        DXNEW = DXOLD * DH + DVX
        DYNEW = DYOLD * DH + DVY
        DZNEW = DZOLD * DH + DVZ
C
        DH = DXNEW * DXNEW + DYNEW * DYNEW + DZNEW * DZNEW
C
        DH = 1.D0 / DH
C
        DXNEW = DXNEW * DH
        DYNEW = DYNEW * DH
        DZNEW = DZNEW * DH
C
      endif
C
C
      RETURN
      END
