      subroutine CSUN03(DJD,LMEAN,DVX,DVY,IERR)
C
CC    Calculates the velocity of the Earth in rect.ecl.coordinates
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:56
C
CA  author : KOD        date: 22-OCT-1991 11:00:10
CU  update : KOD        date: 25-OCT-1991 15:29
C
CT  status: not tested
C
C   general description :
CG
CG  Subroutine to calculate the velocity of the Earth around the Sun
CG  in rectangular ecliptical coordinates for a given Julian Date.
CG  For an easy application to aberration corrections the velocity is
CG  expressed in fractions of the speed of light.
CG
CG  The velocity of the Earth is calculated with respect to the CENTER
CG  of the Sun. This value may differ from the velocity with respect
CG  to the solar system barycenter; the maximum separation between the
CG  center of the sun and the barycenter is about 2.2 solar radii.
CG  The velocity is calculated by the following (approximate) procedure:
CG  first the rectangular ecliptical coordinates of the sun are
CG  determined for two time instants separated by an appropriate
CG  time delay (e.g. one hour) and centered onto the Julian Date
CG  supplied. Then the (negative) difference vector is calculated,
CG  divided by the time delay and normalized with respect to the speed
CG  of light.
CG
CG  Note that the rectangular velocity components refer to the equinox
CG  of date. If they are needed for a standard equinox to a high
CG  precision, they should be precessed appropriately.
CG
CGT Note: The equinox of 2000.0 corresponds to JD 2451545.000,
CGT       the equinox of 1950.0 corresponds to JD 2433282.423,
CGT       the equinox of 1900.0 corresponds to JD 2415020.313.
C
C
C   call_var.          type I/O description
CP
CP  DJD                 R8  I   Julian Date for the Earth velocity
CP
CP  LMEAN               L4  I   true or app. longitude:
CP                                LMEAN = .true.  : true longitude
CP                                LMEAN = .false. : app. longitude
CP
CP  DVX                 R8    O x-velocity (to vernal equinox)
CP  DVY                 R8    O y-velocity (to ecliptical long. 90 deg)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
C
C   routines_called    type     description
CR  CSUN01              SR      calculates long. and dist. of the sun
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DJD, DJD1, DJD2, DT, DLONG1, DLONG2, DDIST1, DDIST2,
     &              DX1, DY1, DX2, DY2, DVX, DVY, DC
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      LOGICAL*4     LMEAN
      CHARACTER*8   RTNAME
C
      PARAMETER   ( DT = 0.04D0 )
      PARAMETER   ( DC = 5.775518304D-3 )
C
      DATA          RTNAME /'CSUN03'/
C
      IERR = 0
C
C     check input values:
C
      if (DJD.lt.0.D0 .or. DJD.gt.3.D6) then
        IERR = 2
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
C
      if (IERR.lt.2) then
C
C       calculate 'first' position of the Sun:
C
        DJD1 = DJD - 0.5D0 * DT
C
        call CSUN01(DJD1,LMEAN,DLONG1,DDIST1,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      endif
C
C
      if (IERR.lt.2) then
C
C       calculate 'second' position of the Sun:
C
        DJD2 = DJD + 0.5D0 * DT
C
        call CSUN01(DJD2,LMEAN,DLONG2,DDIST2,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,20)
        endif
C
      endif
C
C
      if (IERR.lt.2) then
C
C       calculate rectangular positions of the Sun:
C
        DX1 = DDIST1 * cos(DLONG1)
        DY1 = DDIST1 * sin(DLONG1)
C
        DX2 = DDIST2 * cos(DLONG2)
        DY2 = DDIST2 * sin(DLONG2)
C
C       determine the velocity of the Earth:
C
        DVX = DC * ( DX1 - DX2 ) / DT
        DVY = DC * ( DY1 - DY2 ) / DT
C
      endif
C
C
      RETURN
      END
