      subroutine DATEJD(DT,LCHECK,DJD,IERR)
C
CC    Calculates the Julian Date out of the Calendar Date
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:56
C
CA  author : KOD        date: 22-AUG-1989 18:31
CU  update : KOD        date: 28-MAR-1990 20:11
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the Julian Date out of the calendar date.
CG  The calendar date is assumed to be given in the Gregorian system
CG  for dates starting with October 15, 1582, and in the Julian
CG  system until October 4, 1582 (in between it is undefined).
CG
CG  This subroutine is valid for the years  -4712  to  +3500 ,
CG  and has been written according to
CG     van Flandern and Pulkkinen:
CG     'Low-Precision Formulae for Planetary Positions',
CG     Astrophysical Journal Supplement Series 41, 1979, p.392.
CG  and
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.23-25 .
CG
CG  An extended input check is possible for valid dates.
C
C   call_var.          type I/O description
CP  DT                  R8  I   Calendar Date  (YYYYMMDD.HHMMSSS)
CP  LCHECK              L4  I   extended input check if LCHECK=.TRUE.
CP
CP  DJD                 R8    O Julian Date
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning (unusual input values)
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  YMDHMS              SR      splits the variable DT into its parts
CR  CALJD1              SR      converts the Calendar Date to J.D.
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DT, DH, DJD
      REAL*4        HFLAG, SEC
      INTEGER*4     IERR, IOS, IY, IM, ID, IHR, IMT, ISTAT
      LOGICAL*4     LCHECK, LCHK
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'DATEJD'/
C
      IERR=0
C
      DH = DT
      CALL YMDHMS(DH,IY,IM,ID,IHR,IMT,SEC,ISTAT)
CN!   ERROR handling
        if  (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      LCHK=LCHECK
      CALL CALJD1(IY,IM,ID,IHR,IMT,SEC,LCHK,DH,IERR)
CN!       ERROR handling
          if  (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,20)
          endif
C
      DJD=DH
C
      RETURN
      END
