      subroutine DOYYMD(IY,IDOY,IM,ID,IERR)
C
CC    Calculates the Month and Day from the Year and Day of the Year
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:58
C
CA  author : KOD        date: 23-AUG-1989 20:04
CU  update : KOD        date: 28-MAR-1990 15:49
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the Month and Day from the Year and
CG  Day of the Year. The Day of the Year is assumed to be given
CG  in the Gregorian system for dates starting with October 15,
CG  1582, and in the Julian system until October 4, 1582 (in
CG  between it is undefined). For the year 1582 this subroutine
CG  will count the ACTUAL days of the year (which has 355 days)
CG  and will give a warning message for days after October 4.
CG
CG  This subroutine is valid for the years -4712  to  +3500 ,
CG  and has been written according to
CG     van Flandern and Pulkkinen:
CG     'Low-Precision Formulae for Planetary Positions',
CG     Astrophysical Journal Supplement Series 41, 1979, p.392.
CG  and
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.23-25 .
CG
CG  The input date will be checked for validity.
C
C   call_var.          type I/O description
CP  IY                  I4  I   year         (-4712 .. +3500)
CP  IDOY                I4  I   day of year  (1 .. 365,366)
CP
CP  IM                  I4    O month        (1 .. 12)
CP  ID                  I4    O day of month (1 .. 28,29,30,31)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  CALJD1              SR      converts Calendar Date into Julian Date
CR  JDCAL1              SR      converts Julian Date into Calendar Date
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DJD
      REAL*4        HFLAG, sec
      INTEGER*4     IERR, IOS, IY, IDOY, IM, ID, IYEAR, IDAY, IMONTH,
     &              IHR, IMT, ISTAT
      LOGICAL*4     LCHECK
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'DOYYMD'/
C
      IERR = 0
C
C     rough input check:
C
      if (IDOY.gt.366) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Day of Year > 366')
      endif
C
      if (IY.eq.1582 .and. IDOY.gt.277) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,
     &      'Warning: Calendar Reform --> Day of the Year not unique')
      endif
C
      if (IERR.lt.2) then
C
C       calculate the Julian Date for the first day of the year:
C
        IYEAR  = IY
        IMONTH = 1
        IDAY   = 1
        IHR    = 12
        IMT    = 0
        SEC    = 0.0
        LCHECK = .true.
C
        call CALJD1(IYEAR,IMONTH,IDAY,IHR,IMT,SEC,LCHECK,DJD,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      endif
C
      if (IERR.lt.2) then
C
C       add Day of Year:
C
        DJD = DJD + dble(IDOY-1)
C
C       calculate the Calendar Date:
C
        call JDCAL1(DJD,IYEAR,IMONTH,IDAY,IHR,IMT,SEC,IERR)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,20)
        else
          if (IYEAR.eq.IY) then
            IM = IMONTH
            ID = IDAY
          else
            IERR = max(IERR,2)
            call WRERR(RTNAME,IERR,'No leap year')
          endif
        endif
C
      endif
C
      RETURN
      END
