      subroutine ECEQAB(DVX,DVY,DVZ,LDIR,DL,DB,DEPS,DA,DD,IERR)
C
CC  converts ecl. coord. into aberration-corrected equ. coord.
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 16:55
C
CA  author : KOD        date: 22-OCT-1991 10:47
CU  update : KOD        date: 30-OCT-1991 08:11
C
CT  status: not tested
C
C   general description
CG
CG  Subroutine to convert ecliptical coordinates into equatorial
CG  coordinates which are corrected for the effect of aberration.
CG  This correction can be applied in both directions (see LDIR).
CG  The velocities have to be supplied in units of the speed of light
CG  in a right-handed rectangular coordinates system with the x-axis
CG  pointing towards the vernal equinox and the y-axis towards an
CG  ecliptical longitude of 90 degrees. The correction for aberration
CG  performed is non-relativistic.
CG
CG  This routine has been optimized for a frequent conversion/correction
CG  of different positions within a small interval of time. Therefore,
CG  the velocity (DVX,DVY,DVZ) and the obliquity of the ecliptic have
CG  to be provided as arguments. Since these quantities do not change
CG  very quickly (the obliquity being a constant for most applications),
CG  they can be calculated before or may have to be updated only after
CG  a number of calls to this subroutine.
CG
C
C   call_var.          type I/O description
CP
CP  DVX                 R8  I   velocity of the observer in x-direction
CP  DVY                 R8  I   velocity of the observer in y-direction
CP  DVZ                 R8  I   velocity of the observer in z-direction
CP
CP  LDIR                L   I   direction of the correction:
CP                               = .true. :  true pos. --> apparent pos.
CP                               = .false.:  true pos. <-- apparent pos.
CP
CP  DL                  R8  I   ecliptical longitude          (radians)
CP  DB                  R8  I   ecliptical latitude           (radians)
CP
CP  DEPS                R8  I   obliquity of the ecliptic     (radians)
CP
CP  DA                  R8    O Right Ascension               (radians)
CP  DD                  R8    O Declination                   (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DVX, DVY, DVZ, DL, DB, DEPS, DA, DD, DH,
     &              DX1, DY1, DZ1, DX2, DY2, DZ2, DX3, DY3, DZ3,
     &              DSE, DCE, DR, DPH, DTH
      REAL*4        HFLAG
      INTEGER*4     IERR, IOS, ISTAT
      LOGICAL       LDIR
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'ECEQAB'/
C
C
      IERR = 0
C
      DH = dmax1(dabs(DVX),dabs(DVY),dabs(DVZ))
C
      if (DH.gt.1.D0) then
         IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in velocity')
      endif
C
      if (DH.gt.0.1D0) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,
     &      'Warning: correction for aberration is non-relativistic')
      endif
C
      if (DL.lt.0.D0 .or. DL.gt.D2PI) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,'Warning: unusual value for DL')
      endif
C
      if (dabs(DB).gt.DPID2) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input parameter DB')
      endif
C
      if (dabs(DEPS-0.409D0).gt.1.D-2) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input parameter DEPS')
      endif
C
C
      if (IERR.lt.2) then
C
C       convert the ecliptical coordinates into rectangular coordinates:
C
        DR  = 1.D0
        DPH = DL
        DTH = DPID2 - DB
C
        call POLRE1(DR,DPH,DTH,DX1,DY1,DZ1,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      endif
C
C
      if (IERR.lt.2) then
C
C       correct coordinates for aberration:
C
        call CPSAB2(DVX,DVY,DVZ,LDIR,DX1,DY1,DZ1,
     &              DX2,DY2,DZ2,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,20)
        endif
C
      endif
C
C
      if (IERR.lt.2) then
C
C       convert (rect.) ecl.coord. into (rect.) equatorial coord.:
C
        DSE = dsin(DEPS)
        DCE = dcos(DEPS)
C
        DX3 = DX2
        DY3 = DY2 * DCE - DZ2 * DSE
        DZ3 = DY2 * DSE + DZ2 * DCE
C
C       convert rect. coordinates into spherical coord.:
C
        call REPOL1(DX3,DY3,DZ3,DR,DPH,DTH)
C
        DA = DPH
        DD = DPID2 - DTH
C
      endif
C
C
      RETURN
      END
