      subroutine EQUECL(DJD,LMEAN,LDIR,DLOLD,DBOLD,DLNEW,DBNEW,IERR)
C
CC    Converts coordinates between equatorial and ecliptical system
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:02
C
CA  author : KOD        date: 19-JUL-1989 18:31
CU  update : KOD        date: 29-MAR-1990 15:13
CU  update : KOD        date: 17-AUG-1992 10:09 (`1.D-6')
C
CT  status: tested
C
C   general description
CG  Subroutine to convert coordinates between the equatorial and the
CG  ecliptical system (LII,BII).
CG
CG  To convert the TRUE positions, use the MEAN obliquity of the
CG  ecliptic (normal case);
CG  for the APPARENT positions (affected by aberration and nutation)
CG  use the TRUE obliquity.
CG  If the equatorial coordinates refer to a standard equinox
CG  (1950, 2000, ...), the obliquity of the ecliptic for this
CG  epoch should be used.
CG
CG  (Jean Meeus, 'Astronomical Formulae for Calculators',
CG                third edition, 1985, p.43-44)
C
C   call_var.          type I/O description
CP  DJD                 R8  I   Julian Day for the conversion
CP
CP  LMEAN               L4  I   mean or true obliquity of the ecliptic:
CP                                LMEAN = .true.  : mean obliquity
CP                                LMEAN = .false. : true obliquity
CP
CP  LDIR                L4  I   transformation direction:
CP                                LDIR = .true.  : equ --> ecl
CP                                LDIR = .false. : equ <-- ecl
CP
CP  DLOLD               R8  I   old longitude  (radians)
CP  DBOLD               R8  I   old latitude   (radians)
CP
CP  DLNEW               R8    O new longitude  (radians)
CP  DBNEW               R8    O new latitude   (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  EULER1              SR      general coordinate transformation
CR  JDEPS1              SR      calculates mean/true obl. of the ecl.
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DJD, DLOLD, DBOLD, DLNEW, DBNEW, D1, D2, D3,
     &              DEPS, DPHI1, DTHETA1, DPHI2, DTHETA2, DJ
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      LOGICAL*4     LMEAN, LDIR, LMN
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'EQUECL'/
C
      IERR = 0
C
C
      if (DLOLD.lt.-1.D-6 .or. DLOLD.GT.D2PI+1.D-6) then
        IERR = 1
        call WRERR(RTNAME,IERR,'Warning: unusual value for DLOLD')
      endif
C
      if (dabs(DBOLD).gt.DPID2+1.D-6) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input parameter DBOLD')
      endif
C
      if (DJD.lt.0.D0 .or. DJD.gt.3.D6) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
C
      if  (IERR.lt.2)  then
C
        DJ = DJD
        LMN = LMEAN
        call JDEPS1(DJ,LMN,DEPS,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      endif
C
C
      if  (IERR.lt.2)  then
C
        D1 = 0.D0
        D2 = DEPS
        D3 = 0.D0
C
        DPHI1   = DLOLD
        DTHETA1 = DPID2 - DBOLD
C
        if (LDIR) then
          call EULER1(D1,D2,D3,DPHI1,DTHETA1,DPHI2,DTHETA2,ISTAT)
        else
          call EULER1(-D3,-D2,-D1,DPHI1,DTHETA1,DPHI2,DTHETA2,ISTAT)
        endif
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,20)
        else
          DLNEW = DPHI2
          DBNEW = DPID2 - DTHETA2
        endif
C
      endif
C
      RETURN
      END
