      subroutine ERRBX1(DL0,DB0,DBW,DBH,DBT,DDL,DDB,IERR)
C
CC    Calculates the coordinates of the corners of an error box
C
C************************ FFORM VERSION 1.2 ************ 14-DEC-90 10:16
C
CA  author : KOD        date: 28-JUN-1990 20:34
CU  update : KOD        date: 26-OCT-1990 18:23 (no warning in EULER1)
CU  update : KOD        date: 17-AUG-1992 10:11 (`1.D-6')
C
CT  status: tested
C
C   general description
CG
CG  Subroutine to calculate the coordinates of the corners of an
CG  error box which is specified by its width, height, tilt, and
CG  the coordinates of its center. The height parameter determines
CG  the extent of the `vertical' boundaries, which are part of a
CG  great circle on the sphere, while the `horizontal' boundaries
CG  specified by the width parameter are determined as small circles
CG  of equal length on the sphere. The tilt of the error box is
CG  the angle between the symmetry plane of the width boundaries
CG  and the declination line (DB0) running through the center of
CG  the error box, measured counterclockwise. Note that the dimensions
CG  of the source box are required in `true' degrees (i.e., the values
CG  are independent of the declination) to be consistent with any
CG  tilts. The calculation is done in full spherical geometry.
C
C   call_var.          type I/O description
CP
CP  DL0                 R8  I   Right Ascension of the center  (radians)
CP  DB0                         Declination of the center      (radians)
CP
CP  DBW                 R8  I   full width  of the error box   (radians)
CP  DBH                 R8  I   full height of the error box   (radians)
CP  DBT                 R8  I   tilt of the error box          (radians)
CP
CP  DDL                 R8    O Right Ascension of the corners (radians)
CP  DDB                 R8    O Declination     of the corners (radians)
CP
CP  IERR                I4      = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  EULER1              SR      transformation of spherical coordinates
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to flag output stream
CR  DRADRS                      'resets' radians
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DL0, DB0, DBW, DBH, DBT, DDL(4), DDB(4), D1, D2, D3,
     &              DPH1, DTH1, DPH2, DTH2, DW, DH, DRADRS
      REAL*4        HFLAG
      INTEGER*4     IERR, IOS, ISTAT, I
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'ERRBX1'/
C
      IERR = 0
C
C     check input values:
C
      if (max(abs(DL0),DBW,abs(DBT)).gt.D2PI+1.D-6) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,'Unusual input values')
      endif
C
      if ( abs(DB0).gt.DPID2+1.D-6 .or. DBH.gt.DPI .or.
     &     DBW.lt.0.D0 .or. DBH.lt.0.D0 ) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input values')
      endif
C
C
      if (IERR.lt.2) then
C
        do I = 1, 4
C
          if (I.le.2) then
            DW = D2PI - 0.5D0 * DBW
          else
            DW = 0.5D0 * DBW
          endif
C
          if (I.eq.1 .or. I.eq.4) then
            DH =  0.5D0 * DBH
          else
            DH = -0.5D0 * DBH
          endif
C
          D1 = 0.D0
          D2 =  DBT
          D3 = 0.D0
C
          DPH1 = DRADRS(DW)
          DTH1 = DPID2 - DH
C
          CALL EULER1(D1,D2,D3,DPH1,DTH1,DPH2,DTH2,ISTAT)
C
          if (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,10)
          endif

          if (IERR.lt.2) then
C
            D1 =  DPID2
            D2 =  DB0
            D3 = DRADRS(-DPID2-DL0)
C
            DPH1 = DPH2
            DTH1 = DTH2
C
            CALL EULER1(D1,D2,D3,DPH1,DTH1,DPH2,DTH2,ISTAT)
C
            if (ISTAT.gt.1) then
              IERR = max(IERR,ISTAT)
              call ERRSTC(RTNAME,20)
            else
              DDL(I) = DPH2
              DDB(I) = DPID2 - DTH2
            endif
C
          endif
C
        enddo
C
      endif
C
C
      RETURN
      END
