      subroutine EULER1(D1,D2,D3,DPH1,DTH1,DPH2,DTH2,IERR)
C
CC    General transformation of spherical coordinates
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:03
C
CA  author : KOD        date: 15-JUL-1989 18:31
CU  update : KOD        date: 20-MAR-1990 14:57
CU  update : KOD        date: 17-AUG-1992 09:38 (`1.D-6')
C
CT  status: tested
C
C   general description
CG
CG  Subroutine to convert spherical coordinates between coordinate
CG  systems which are rotated with respect to each other.
CG
CG  This subroutine converts the azimuthal and polar angles
CG  (DPH1,DTH1), given in mathematical notation and in radians,
CG  into the corresponding angles with respect to a coordinate
CG  system which orientation is given by the EULER angles (D1,D2,D3)
CG  in the following way:
CG
CG  The original cartesian coordinate system (X0,Y0,Z0) is rotated
CG  in three steps:
CG
CGT   1) rotation around the Z0-axis by the angle D1  --->  (X1,Y1,Z1)
CGT   2) rotation around the X1-axis by the angle D2  --->  (X2,Y2,Z2)
CGT   3) rotation around the Z2-axis by the angle D3  --->  (X3,Y3,Z3)
CG
CG  The calculation is accelerated by using differences of angles.
C
C   call_var.          type I/O description
CP  D1                  R8  I   EULER angle 1   (radians, -2 pi .. 2 pi)
CP  D2                  R8  I   EULER angle 2   (radians, -2 pi .. 2 pi)
CP  D3                  R8  I   EULER angle 3   (radians, -2 pi .. 2 pi)
CP
CP  DPH1                R8  I   original  azimuthal angle (rad, 0..2 pi)
CP  DTH1                R8  I   original    polar   angle (rad, 0..pi)
CP
CP  DPH2                R8    O resulting azimuthal angle (rad, 0..2 pi)
CP  DTH2                R8    O resulting   polar   angle (rad, 0..pi)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  REPOL1              SR      cartesian to polar coordinate conversion
CR  DRADRS              R8      'resets' radians
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        D1, D2, D3, DPH1, DPH2, DTH1, DTH2,
     &              DST, DCT, DH, DS1, DC1, DS2, DC2, DX, DY, DZ,
     &              DR, DPHI, DTHETA, DRADRS
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'EULER1'/
C
      IERR = 0
C
      if (max(dabs(D1),dabs(D2),dabs(D3)).gt.D2PI .or.
     &    DPH1.lt.0.D0) then
        IERR = max(IERR,1)
        call WRERR(RTNAME,IERR,'Warning: Unusual input parameters')
      endif
C
      if (DTH1.lt.-1.D-6 .or. dabs(DTH1).gt.DPI+1.D-6) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in input parameters')
      else
C
        DST = sin(DTH1)
        DCT = cos(DTH1)
C
        DH  = DPH1 - D1
        DS1 = sin(DH)
        DC1 = cos(DH)
C
        DS2 = sin(D2)
        DC2 = cos(D2)
C
        DX = DST*DC1
        DY = DST*DS1*DC2 + DCT*DS2
        DZ =-DST*DS1*DS2 + DCT*DC2
C
        call REPOL1(DX,DY,DZ,DR,DPHI,DTHETA)
C
        if (DABS(DR-1.D0).gt.1.E-6) then
          IERR = max(IERR,2)
        else
          DPH2 = DRADRS(DPHI - D3)
          DTH2 = DTHETA
        endif
C
      endif
C
      RETURN
      END
