      subroutine JDCAL1(DJD,IY,IM,ID,IHR,IMT,SEC,IERR)
C
CC    Calculates the Calendar Date out of the Julian Date
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:04
C
CA  author : KOD        date: 19-JUL-1989 18:31
CU  update : KOD        date: 29-MAR-1990 15:36
C
CT  status: tested (08-AUG-1989 17:45 / KOD)
C
C   general description
CG  Subroutine to calculate the Calendar Date out of the Julian Date.
CG
CG  The calendar date will be given in the Gregorian system for
CG  dates starting with October 15, 1582, and in the Julian system
CG  until October 4, 1582  (which precedes the Oct.15 immediately).
CG
CG  This subroutine is valid for the years  -4712  to  +3500 ,
CG  (cf. 'Sky and Telescope, May 1984, p.455) and has been written
CG  according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.26 .
CG  For negative years only the variable IY will be negative.
C
C   call_var.          type I/O description
CP  DJD                 R8  I   Julian Date
CP
CP  IY                  I4    O year         (-4712 .. +3500)
CP  IM                  I4    O month        (1 .. 12)
CP  ID                  I4    O day of month (1 .. 28,29,30,31)
CP  IHR                 I4    O hours        (0 .. 23)
CP  IMT                 I4    O minutes      (0 .. 59)
CP  SEC                 R4    O seconds      (0.0 .. 59.999...)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  CNVDMS              SR      splits fractional part
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DJD, DH, DF
      REAL*4        HFLAG, SEC, SEC1
      INTEGER*4     IERR ,IOS, IY, IM, ID, IHR, IMT, JD, IA, IB, IC,
     &              IG, IE, IHR1, IMT1, ISTAT
      LOGICAL       LPLUS
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'JDCAL1 '/
C
      IERR = 0
C
      if (DJD.lt.0.D0 .or. DJD.gt.2999773.5D0) then
        IERR = 2
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
      if (IERR.lt.2) then
        DH = DJD + 0.5D0
        JD = idint(DH)
        DF = DH - dble(JD)
C
        if (JD.lt.2299161) then
          IA = JD
        else
          IA = idint( (dble(JD)-1867216.25D0) / 36524.25D0 )
          IA = JD + 1 + IA - IA/4
        endif
C
        IB = IA + 1524
        IC = idint( (dble(IB)-122.1D0) / 365.25D0 )
        IG = idint( 365.25D0 * dble(IC) )
        IE = idint( dble(IB-IG) / 30.6001D0 )
C
        ID = IB - IG - int( 30.6004 * real(IE) )
C
        if (IE.le.13) then
          IM = IE - 1
        else
          IM = IE - 13
        endif
C
        if (IM.ge.3) then
          IY = IC - 4716
        else
          IY = IC - 4715
        endif
C
        DF = DF * 24.D0
        LPLUS = .TRUE.
        call CNVDMS(DF,LPLUS,IHR1,IMT1,SEC1,ISTAT)
C
        if (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        else
          IHR = IHR1
          IMT = IMT1
          SEC = SEC1
        endif
C
      endif
C
      RETURN
      END
