      subroutine JDCAL2(DJD,ITD,ITS,IERR)
C
CC    Calculates the Calendar Date out of the Julian Date.
C
C************************ FFORM VERSION 1.2 ************ 16-MAR-92 16:04
C
CA  author : KOD        date: 9-MAR-1992 16:50
CU  update : KOD        date: 11-MAR-1992 16:18
CU  update : KOD        date: 11-MAR-1992 16:58
C
CT  status: tested
C
C   general description
CG
CG  This subroutine calculates the Calendar Date out of the Julian Date
CG  for the years 1950 to 2049. The Calendar Date is contained in the
CG  integers values ITD (YYMMDD) and ITS (msec of the day in UT).
C
C   call_var.          type I/O description
CP
CP  DJD                         Julian Date
CP
CP  ITD                 I4    O Calendar Date  (YYMMDD)
CP  ITS                 I4    O Universal Time (msec of the day)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  JDCAL1              SR      calculates the calendar date
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC                      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DJD
      REAL*4        HFLAG, SEC
      INTEGER*4     IERR, IOS, ISTAT, ITD, ITS, IY, IM, ID, IHR, IMT
      CHARACTER*4   CH4
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'JDCAL2'/
C
      IERR = 0
C
C     check input values:
C
      if (DJD.lt.2433282.5D0 .or. DJD.gt.2469807.5D0) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in Julian Date; < 1950 or > 2049')
      endif
C
C
      if (IERR.lt.2) then
C
        call JDCAL1(DJD,IY,IM,ID,IHR,IMT,SEC,ISTAT)
C
        if  (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        else
          write(CH4,'(I4)') IY
          read(CH4,'(2X,I2)') IY
          ITD = IY * 10000 + IM * 100 + ID
          ITS = (IHR * 3600 + IMT * 60) * 1000 + nint(SEC*1.E3)
        endif
C
      endif
C
      RETURN
      END
