      subroutine JDDAT3(DJD,CHDAT,IERR)
C
CC    Calculates the Calendar Date out of the Julian Date
C
C************************ FFORM VERSION 1.2 ************  2-APR-90 15:26
C
CA  author : KOD        date: 15-NOV-2016
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the Calendar Date out of the Julian Date.
CG
CG  The calendar date will be given in the Gregorian system for
CG  dates starting with October 15, 1582, and in the Julian system
CG  until October 4, 1582  (which precedes the Oct.15 immediately).
CG
CG  This subroutine is valid for the years  -4712  to  +3500 ,
CG  (cf. 'Sky and Telescope, May 1984, p.455) and has been written
CG  according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.26 .
CG
CG  This subroutine produces a string of the form
CG  'YYYY.MM.DD / HH:MM:SS.SS'  (Maximum resolution: 10 msec)
C
C   call_var.          type I/O description
CP  DJD                 R8  I   Julian Date
CP
CP  CHDAT               C   ?/? string containing the calendar date
CP                              'YYYY' to 'YYYY.MM.DD / HH:MM:SS.SS'
CP
CP                               possible lengths 'L' of CHDAT :
CP                               L = 19 : 'yyyy-mm-ddThh:mm:ss'
CP
CP                               The values for the year, month
CP                               and day will not be rounded,
CP                               the values for the hour, minute
CP                               and second will be rounded.
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  JDCAL1              SR      Julian Date to Calendar Date
CR  CHDATE              SR      converts Calendar Date into a string
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DJD, DJ
      REAL*4        HFLAG, SEC
      INTEGER*4     IERR ,IOS, IYR, IMTH, IDAY, IHR, IMIN, MSEC, ISTAT
      LOGICAL*4     LCHECK
      CHARACTER*(*) CHDAT
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'JDDAT2'/
C
      IERR = 0
C
      DJ = DJD
      call JDCAL1(DJ,IYR,IMTH,IDAY,IHR,IMIN,SEC,ISTAT)
CN!     ERROR handling
        if  (ISTAT.gt.1) then
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
        endif
C
      LCHECK=.true.
      call CHDATE(IYR,IMTH,IDAY,IHR,IMIN,SEC,LCHECK,CHDAT,ISTAT)
C
CN!   ERROR handling
      if  (ISTAT.gt.1) then
        IERR = max(IERR,ISTAT)
        call ERRSTC(RTNAME,20)
      endif
C
      RETURN
      END
