      subroutine JDEPS1(DJD,LMEAN,DEPS,IERR)
C
CC    Calculates the MEAN/TRUE obliquity of the ecl. for the Jul. Date
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:05
C
CA  author : KOD        date: 29-AUG-1989 17:22
CU  update : KOD        date: 29-MAR-1990 15:53
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the MEAN/TRUE obliquity of the ecliptic
CG  for a given Julian Date, according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.44,69,70,81.
CG
CG  The parameters for calculating the mean obliquity have been
CG  taken from 'THE ASTRONOMICAL ALMANACH', 1984, S21.
CG
CG  For APPARENT positions (affected by aberration and nutation)
CG  use the TRUE obliquity, otherwise the MEAN obliquity.
C
C   call_var.          type I/O description
CP  DJD                 R8  I   Julian Date
CP
CP  LMEAN               L4  I   mean or true obliquity of the ecliptic:
CP                                LMEAN = .true.  : mean obliquity
CP                                LMEAN = .false. : true obliquity
CP
CP  DEPS                R8    O obliquity of the ecliptic  (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  JDNUT1              SR      calculates the nutation parameters
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DJD, DEPS, DJD0, DYEAR, D1, D2, D3, D4, DT, DP,
     &              DE, DJ
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      LOGICAL*4     LMEAN
      CHARACTER*8   RTNAME
C
      PARAMETER ( DJD0 = 2451545.D0 )
      PARAMETER ( DYEAR =  36525.D0 )
C
      PARAMETER ( D1 =  0.40909280422D0 )
      PARAMETER ( D2 = -2.26965525D-4 )
      PARAMETER ( D3 = -2.86040D-9 )
      PARAMETER ( D4 =  8.78967D-9 )
C
      DATA          RTNAME /'JDEPS1'/
C
      IERR = 0
C
      if (DJD.lt.0.D0 .or. DJD.gt.3.D6) then
        IERR = 2
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
      if (IERR.lt.2) then
C
        DT = (DJD - DJD0) / DYEAR
C
        DEPS = D1 + ( D2 + ( D3 + D4 * DT ) * DT ) * DT
C
        if (.not.LMEAN) then
C
          DJ = DJD
          call JDNUT1(DJ,DP,DE,ISTAT)
C
          if  (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,10)
          else
            DEPS = DEPS + DE
          endif
C
        endif
C
      endif
C
      RETURN
      END
