      subroutine JDSID1(DJD,LMEAN,DSID,IERR)
C
CC    Calculates the mean/apparent sid. time at Greenwich from the JD
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:06
C
CA  author : KOD        date: 05-SEP-1989 16:20
CU  update : KOD        date: 30-MAR-1990 16:11
CU  update : PAUL       date: 16-NOV-1992 16:05 null characters deleted
C
CT  status: tested
C
C   general description
CG
CG  Subroutine to calculate the mean/apparent sidereal time
CG  at Greenwich from the Julian Date, according to
CG     R.W.Sinnott, 'Astronomical Computing',
CG                   Sky and Telescope, 1984, p.558-559 .
CG
CG  The formula used has been adopted by the International
CG  Astronomical Union (Sky and Telescope, June, 1982, p.562).
CG
CG  Values to check the results (Sky and Telescope, June 1984, p.559):
CG
CGT        JD:        0.0   GMST = 16:13:22
CGT        JD: 170 5426.1   GMST = 01:45:59
CGT        JD: 244 5700.5   GMST = 06:39:23
CGT        JD: 245 1545.0   GMST = 18:41:51
CGT        JD: 299 9624.2   GMST = 13:41:28
CG
CG  For APPARENT positions (affected by aberration and nutation)
CG  use the APPARENT sid. time, otherwise the MEAN sidereal time.
CG
CG  For consistency with the other subroutines the sidereal time
CG  will be given in radians.
C
C   call_var.          type I/O description
CP
CP  DJD                 R8  I   Julian Date
CP
CP  LMEAN               L4  I   mean or true siderial time:
CP                                LMEAN = .true.  : mean sid. time
CP                                LMEAN = .false. : app. sid. time
CP
CP  DSID                R8    O sidereal time ( radians ! )
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  DRADRS              R8      'resets' radians
CR  JDEPS1              SR      calculates obliquity of the ecliptic
CR  JDNUT1              SR      calculates the nutation parameters
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DJD, DSID, DJD0, DYEAR, DA, DB, DC, DD, DF, DJD0UT,
     &              DT, DFRC, DRADRS, DSID0, DEPS, DP, DE, DH, DJ
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      LOGICAL*4     LMEAN, LMN
      CHARACTER*8   RTNAME
C
      PARAMETER ( DJD0 = 2451545.D0 )
      PARAMETER ( DYEAR =  36525.D0 )
C
      PARAMETER ( DA =   1.7533685592D0  )
      PARAMETER ( DB = 628.33197068884D0 )
      PARAMETER ( DC =   6.770714D-6     )
      PARAMETER ( DD =  -4.509D-10       )
      PARAMETER ( DF =   1.002737908D0   )
C
      DATA          RTNAME /'JDSID1'/
C
      IERR = 0
C
      if (DJD.lt.0.D0 .or. DJD.gt.3.D6) then
        IERR = 2
        call WRERR(RTNAME,IERR,'Error in the input parameter DJD')
      endif
C
      if (IERR.lt.2) then
C
C       calculate the nearest Julian Date at 00:00 UT:
C
        DJD0UT = DNINT(DJD-0.5D0)+0.5D0
C
C       calculate the corresponding sidereal time:
C
        DT = (DJD0UT-DJD0) / DYEAR
        DSID0 = DA + (DB + (DC + DD * DT ) * DT ) * DT
C
C       find sidereal time for the given hours:
C
        DFRC = DJD - DJD0UT
        DT = DSID0 + DFRC * D2PI * DF
        DSID = DRADRS(DT)
C
        if (.not.LMEAN) then
C
          DJ = DJD
          LMN = LMEAN
          call JDEPS1(DJ,LMN,DEPS,ISTAT)
          if  (ISTAT.gt.1) then
            IERR = max(IERR,ISTAT)
            call ERRSTC(RTNAME,10)
          endif
C
          if (IERR.lt.2) then
            call JDNUT1(DJ,DP,DE,IERR)
            if  (ISTAT.gt.1) then
              IERR = max(IERR,ISTAT)
              call ERRSTC(RTNAME,20)
            endif
          endif
C
          if (IERR.lt.2) then
            DH = DP * cos(DEPS)
            DSID = DRADRS ( DSID + DH )
          endif
C
        endif
      endif
C
      RETURN
      END
