      subroutine PARLX1(DLAT,DHT,DPRLX,DHR,DAOLD,DDOLD,LDIR,
     &                  DANEW,DDNEW,IERR)
C
CC    Corrects the equatorial coordinates for parallax
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:08
C
CA  author : KOD        date: 04-OCT-1989 18:35
CU  update : KOD        date: 29-MAR-1990 16:24
C
CT  status: tested
C
C   general description
CG  Subroutine to convert between GEOcentric and TOPOcentric
CG  equatorial coordinates (of the Moon, Sun, a planet or comet),
CG  according to
CG     Jean Meeus, 'Astronomical Formulae for Calculators',
CG                 third edition, 1985, p.143-146 .
CG
CG  The conversion from topocentric to geocentric coordinates is
CG  less accurrate; this difference might however only be noticed
CG  for the moon where the error is usually around 20 arc seconds.
C
C   call_var.          type I/O description
CP  DLAT                R8  I   geographical latitude  (radians)
CP  DHT                 R8  I   height above sea level  (meters)
CP  DPRLX               R8  I   parallax               (radians)
CP  DHR                 R8  I   hour angle             (radians)
CP  DAOLD               R8  I   'old' right ascension  (radians)
CP  DDOLD               R8  I   'old' declination      (radians)
CP
CP  LDIR                L4  I   transformation direction:
CP                                LDIR = .true.  : geo. --> topo.
CP                                LDIR = .false. : geo. <-- topo.
CP
CP  DANEW               R8    O 'new' right ascension  (radians)
CP  DDNEW               R8    O 'new' declination      (radians)
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  GEORCO              SR      calculates geocentric rect. coordinates
CR  WRERR               SR      formats error code in standard form
CR  ERRSTC              SR      continue error stack for one level
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DLAT, DHT, DPRLX, DHR, DAOLD, DDOLD, DANEW, DDNEW,
     &              DRSPHI, DRCPHI, DH1, DH2, DACOR, DDCOR, DSPRLX,
     &              DH, DLT
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, ISTAT
      LOGICAL*4     LDIR
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'PARLX1'/
C
      IERR = 0
C     check input values
C
      if (DPRLX.lt.0.D0 .or. DPRLX.gt.0.02D0 .or. dabs(DHR).gt.DPI .or.
     &    DAOLD.lt.0.D0 .or. DAOLD.gt.D2PI .or. dabs(DDOLD).gt.DPI) then
C
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in the input values')
      endif
C
      if (IERR.lt.2) then
C
C       calculate the geocentric rectangular coordinates
C
        DLT = DLAT
        DH = DHT
        call GEORCO(DLT,DH,DRSPHI,DRCPHI,ISTAT)
C
        if  (ISTAT.gt.1) then
C
          IERR = max(IERR,ISTAT)
          call ERRSTC(RTNAME,10)
C
        else
C
          DSPRLX = sin(DPRLX)
C
          DH1 = -DRCPHI * DSPRLX * sin(DHR)
          DH2 = cos(DDOLD) - DRCPHI * DSPRLX * cos(DHR)
          DACOR = atan2 ( DH1, DH2 )
C
          DH1 = ( sin(DDOLD) - DRSPHI * DSPRLX ) * cos(DACOR)
          DH2 = cos(DDOLD) - DRCPHI * DSPRLX * cos(DHR)
          DH = atan2 ( DH1, DH2 )
          DDCOR = DH - DDOLD
C
          if (LDIR) then
            DANEW = DAOLD + DACOR
            DDNEW = DDOLD + DDCOR
          else
            DANEW = DAOLD - DACOR
            DDNEW = DDOLD - DDCOR
          endif
C
        endif
      endif
C
      RETURN
      END
