      subroutine PHASE1(DT0,DPER,DT,DPH,NPER,IERR)
C
CC    Calculates the phase and number of extrapolated periods
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:08
C
CA  author : KOD        date: 13-OCT-1989 14:48
CU  update : KOD        date: 20-MAR-1990 15:07
C
CT  status: tested
C
C   general description
CG  Subroutine to calculate the phase and number of extrapolated
CG  (full) periods.
C
C   call_var.          type I/O description
CP  DT0                 R8  I   reference epoch
CP  DPER                R8  I   period             (same unit as DT0)
CP
CP  DT                  R8  I   time of interest   (same unit as DT0)
CP
CP  DPH                 R8    O corresponding phase  ( 0 .. 1 )
CP  NPER                I4    O number of extrapolated full periods
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DT0, DPER, DT, DPH, DH
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS, NPER
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'PHASE1'/
C
      IERR = 0
C
      if (DPER.le.0.D0) then
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error: negative period')
      endif
C
      if (IERR.lt.2) then
C
        DH = (DT - DT0) / DPER
        NPER = int(DH)
        DH = DH - dble(NPER)
        if (DH.lt.0.D0) DH = DH + 1.D0
        DPH = DH
C
      endif
C
      RETURN
      END
