      subroutine REFRA1(DHOLD,LDIR,DHNEW,IERR)
C
CC    Corrects the elevation for atmospheric refraction
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:09
C
CA  author : KOD        date: 03-OCT-1989 17:16
CU  update : KOD        date: 20-MAR-1990 15:08
C
CT  status: tested
C
C   general description
CG  Subroutine to correct the elevation for the effect of
CG  atmospheric refraction (in both directions), according to
CG     R.W.Sinnott, 'Astronomical Computing',
CG                   Sky and Telescope, 1986, p.70 .
CG
CG  The formula from correcting the apparent elevation was given
CG  by G. Bennett (Univ.of New South Wales) in 1982 and is accurate
CG  to 0.07 arc minutes for all elevations, when the observation is
CG  made at sea level, at an atm.pressure of 1010 millibars and
CG  a temperature of 10 degrees Celsius.
CG  The inverse formula (by Th.Saemundsson) is consistent with
CG  Bennett's to within 0.1 arc minute.
C
C   call_var.          type I/O description
CP  DHOLD               R8  I   'old' elevation    (radians)
CP
CP  LDIR                L4  I   transformation direction:
CP                                LDIR = .true.  : app. --> true
CP                                LDIR = .false. : app. <-- true
CP
CP  DHNEW               R8    O 'new' elevation    (radians)
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$COMMON:CGENL.CMN          general parameter common block
CI  R$INCLUDE:IGENL.INC         parameter block with trig. constants
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
c*
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
      REAL*8        DPI, D2PI, DPID2, DPI180, D180PI     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI    =  3.141592653589793238D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( D2PI   =  6.283185307179586477D0 )     ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPID2  =  1.5707963267948966192D0 )    ! R$INCLUDE:IGENL.INC
      PARAMETER ( DPI180 =  0.017453292519943295769D0 )  ! R$INCLUDE:IGENL.INC
      PARAMETER ( D180PI =  57.29577951308232088D0 )     ! R$INCLUDE:IGENL.INC
c     ---------------------------------------------------! R$INCLUDE:IGENL.INC
C
      REAL*8        DHOLD, DHNEW, DHCOR, DH
      REAL*4        HFLAG
      INTEGER*4     IERR ,IOS
      LOGICAL       LDIR
      CHARACTER*8   RTNAME
C
      DATA          RTNAME /'REFRA1'/
C
      IERR = 0
C
      if ((LDIR .and. DHOLD.lt.0.D0) .or.
     &    (.not.LDIR .and. DHOLD.lt.-1.1D-2) .or.
     &    DHOLD.gt.DPID2) then
C
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in the input parameter DHOLD')
        write(*,*) 'dhold = ',dhold
C
      else
C
        DH = DHOLD / DPI180
C
        if (LDIR) then
          DHCOR = -1.00D0 / tan((DH + 7.31D0 / (DH + 4.40D0))*DPI180 )
        else
          DHCOR =  1.02D0 / tan((DH + 10.3D0 / (DH + 5.11D0))*DPI180 )
        endif
C
        DH = DHOLD + DHCOR * DPI180 / 60.D0
C
        DHNEW = min(DH,DPID2)
C
      endif
C
C
      RETURN
      END
