      subroutine YMDHMS(DT,IY,IM,ID,IHR,IMT,SEC,IERR)
C
CC    Splits the calendar date into its components
C
C************************ FFORM VERSION 1.2 ************ 30-MAR-90 17:11
C
CA  author : KOD        date: 19-JUL-1989 18:31
CU  update : KOD        date: 28-MAR-1990 15:52
C
CT  status: tested (02.08.1989 / K.Dennerl)
C
C   general description
CG  Subroutine to split the calendar date, supplied as a single
CG  number in the form YYYYMMDD.HHMMSSS, into its components.
CG  The years may cover the range -9999 .. +9999.
CG  In case of negative years only the year IY will be negative.
CG  Resolution (given by REAL*8): 10~msec.
C
C   call_var.          type I/O description
CP  DT                  R8  I   calendar date (YYYYMMDD.HHMMSSS)
CP
CP  IY                  I4    O year
CP  IM                  I4    O month
CP  ID                  I4    O day
CP  IHR                 I4    O hour
CP  IMT                 I4    O minute
CP  SEC                 R4    O second
CP
CP  IERR                I4    O = 0 no error
CP                              = 1 warning
CP                              = 2 error
CP                              = 3 severe error
C
C   include_block name          description
CI  R$INCLUDE:ICGENL.INC        general parameter common block
C
C   routines_called    type     description
CR  WRERR               SR      formats error code in standard form
CR  HFLAG               R4      output flag handling routine
CR  WRFLAG              SR      writes to FLAG output stream
C
C   extensions/system calls     description
CX
C
C***********************************************************************
C
C   variables   meaning
C
C
      IMPLICIT NONE
c*
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
      CHARACTER*265 OUTPT                                ! R$INCLUDE:ICGENL.INC
      REAL*4        PI, RAD, DEG                         ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( PI  = 3.141592654 )                  ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( RAD = 0.0174532925 )                 ! R$INCLUDE:ICGENL.INC
      PARAMETER   ( DEG = 57.29577951 )                  ! R$INCLUDE:ICGENL.INC
c     ---------------------------------------------------! R$INCLUDE:ICGENL.INC
C
      REAL*8        DT, DH
      REAL*4        HFLAG, SEC
      INTEGER*4     IERR, IOS, IY, IM, ID, IHR, IMT, I1, I2, ISEC1,
     &              ISEC2
      LOGICAL*4     LPLUS
      CHARACTER*8   RTNAME, CHDAT1, CHDAT2
C
      DATA          RTNAME /'YMDHMS'/
C
      IERR = 0
C
C     extract sign:
C
      LPLUS = (DT.ge.0.D0)
      DH = dabs(DT)
C
C     check length of calendar date:
C
      if (DH.gt.99991231.2359599D0) then
C
        IERR = max(IERR,2)
        call WRERR(RTNAME,IERR,'Error in IY')
C
      else
C
C       split according to decimal point:
C
        I1 = int(DH)
        I2 = nint((DH-int(DH))*1.D8)
        write(CHDAT1,'(I8.8)') I1
        write(CHDAT2,'(I8.8)') I2
C
C       read individual parts:
C
        read(CHDAT1,'(I4,I2,I2)') IY, IM, ID
        read(CHDAT2,'(I2,I2,I2,I2)') IHR, IMT, ISEC1, ISEC2
C
C       reconstruct seconds:  (rounded to 10 msec)
C
        SEC = real(ISEC1) + real(ISEC2)*1.E-2
C
C       (rough) check for valid calendar date:
C
        if (IM.lt.1 .or. IM.gt.12 .or. ID.lt.1 .or. ID.gt.31 .or.
     &      IHR.gt.23 .or. IMT.gt.59 .or. SEC.gt.60.0) then
          IERR = max(IERR,2)
          call WRERR(RTNAME,IERR,'Error in IM, ID, IHR, IMT, SEC')
        endif
C
C       add sign:
C
        if (.not. LPLUS)  IY = -IY
C
      endif
C
      RETURN
      END
